#line 1 "giscanner/scannerlexer.c"

#line 3 "giscanner/scannerlexer.c"

#define  YY_INT_ALIGNED short int

/* A lexical scanner generated by flex */

#define FLEX_SCANNER
#define YY_FLEX_MAJOR_VERSION 2
#define YY_FLEX_MINOR_VERSION 6
#define YY_FLEX_SUBMINOR_VERSION 4
#if YY_FLEX_SUBMINOR_VERSION > 0
#define FLEX_BETA
#endif

/* First, we deal with  platform-specific or compiler-specific issues. */

/* begin standard C headers. */
#include <stdio.h>
#include <string.h>
#include <errno.h>
#include <stdlib.h>

/* end standard C headers. */

/* flex integer type definitions */

#ifndef FLEXINT_H
#define FLEXINT_H

/* C99 systems have <inttypes.h>. Non-C99 systems may or may not. */

#if defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L

/* C99 says to define __STDC_LIMIT_MACROS before including stdint.h,
 * if you want the limit (max/min) macros for int types. 
 */
#ifndef __STDC_LIMIT_MACROS
#define __STDC_LIMIT_MACROS 1
#endif

#include <inttypes.h>
typedef int8_t flex_int8_t;
typedef uint8_t flex_uint8_t;
typedef int16_t flex_int16_t;
typedef uint16_t flex_uint16_t;
typedef int32_t flex_int32_t;
typedef uint32_t flex_uint32_t;
#else
typedef signed char flex_int8_t;
typedef short int flex_int16_t;
typedef int flex_int32_t;
typedef unsigned char flex_uint8_t; 
typedef unsigned short int flex_uint16_t;
typedef unsigned int flex_uint32_t;

/* Limits of integral types. */
#ifndef INT8_MIN
#define INT8_MIN               (-128)
#endif
#ifndef INT16_MIN
#define INT16_MIN              (-32767-1)
#endif
#ifndef INT32_MIN
#define INT32_MIN              (-2147483647-1)
#endif
#ifndef INT8_MAX
#define INT8_MAX               (127)
#endif
#ifndef INT16_MAX
#define INT16_MAX              (32767)
#endif
#ifndef INT32_MAX
#define INT32_MAX              (2147483647)
#endif
#ifndef UINT8_MAX
#define UINT8_MAX              (255U)
#endif
#ifndef UINT16_MAX
#define UINT16_MAX             (65535U)
#endif
#ifndef UINT32_MAX
#define UINT32_MAX             (4294967295U)
#endif

#ifndef SIZE_MAX
#define SIZE_MAX               (~(size_t)0)
#endif

#endif /* ! C99 */

#endif /* ! FLEXINT_H */

/* begin standard C++ headers. */

/* TODO: this is always defined, so inline it */
#define yyconst const

#if defined(__GNUC__) && __GNUC__ >= 3
#define yynoreturn __attribute__((__noreturn__))
#else
#define yynoreturn
#endif

/* Returned upon end-of-file. */
#define YY_NULL 0

/* Promotes a possibly negative, possibly signed char to an
 *   integer in range [0..255] for use as an array index.
 */
#define YY_SC_TO_UI(c) ((YY_CHAR) (c))

/* Enter a start condition.  This macro really ought to take a parameter,
 * but we do it the disgusting crufty way forced on us by the ()-less
 * definition of BEGIN.
 */
#define BEGIN (yy_start) = 1 + 2 *
/* Translate the current start state into a value that can be later handed
 * to BEGIN to return to the state.  The YYSTATE alias is for lex
 * compatibility.
 */
#define YY_START (((yy_start) - 1) / 2)
#define YYSTATE YY_START
/* Action number for EOF rule of a given start state. */
#define YY_STATE_EOF(state) (YY_END_OF_BUFFER + state + 1)
/* Special action meaning "start processing a new file". */
#define YY_NEW_FILE yyrestart( yyin  )
#define YY_END_OF_BUFFER_CHAR 0

/* Size of default input buffer. */
#ifndef YY_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k.
 * Moreover, YY_BUF_SIZE is 2*YY_READ_BUF_SIZE in the general case.
 * Ditto for the __ia64__ case accordingly.
 */
#define YY_BUF_SIZE 32768
#else
#define YY_BUF_SIZE 16384
#endif /* __ia64__ */
#endif

/* The state buf must be large enough to hold one state per character in the main buffer.
 */
#define YY_STATE_BUF_SIZE   ((YY_BUF_SIZE + 2) * sizeof(yy_state_type))

#ifndef YY_TYPEDEF_YY_BUFFER_STATE
#define YY_TYPEDEF_YY_BUFFER_STATE
typedef struct yy_buffer_state *YY_BUFFER_STATE;
#endif

#ifndef YY_TYPEDEF_YY_SIZE_T
#define YY_TYPEDEF_YY_SIZE_T
typedef size_t yy_size_t;
#endif

extern int yyleng;

extern FILE *yyin, *yyout;

#define EOB_ACT_CONTINUE_SCAN 0
#define EOB_ACT_END_OF_FILE 1
#define EOB_ACT_LAST_MATCH 2
    
    #define YY_LESS_LINENO(n)
    #define YY_LINENO_REWIND_TO(ptr)
    
/* Return all but the first "n" matched characters back to the input stream. */
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		*yy_cp = (yy_hold_char); \
		YY_RESTORE_YY_MORE_OFFSET \
		(yy_c_buf_p) = yy_cp = yy_bp + yyless_macro_arg - YY_MORE_ADJ; \
		YY_DO_BEFORE_ACTION; /* set up yytext again */ \
		} \
	while ( 0 )
#define unput(c) yyunput( c, (yytext_ptr)  )

#ifndef YY_STRUCT_YY_BUFFER_STATE
#define YY_STRUCT_YY_BUFFER_STATE
struct yy_buffer_state
	{
	FILE *yy_input_file;

	char *yy_ch_buf;		/* input buffer */
	char *yy_buf_pos;		/* current position in input buffer */

	/* Size of input buffer in bytes, not including room for EOB
	 * characters.
	 */
	int yy_buf_size;

	/* Number of characters read into yy_ch_buf, not including EOB
	 * characters.
	 */
	int yy_n_chars;

	/* Whether we "own" the buffer - i.e., we know we created it,
	 * and can realloc() it to grow it, and should free() it to
	 * delete it.
	 */
	int yy_is_our_buffer;

	/* Whether this is an "interactive" input source; if so, and
	 * if we're using stdio for input, then we want to use getc()
	 * instead of fread(), to make sure we stop fetching input after
	 * each newline.
	 */
	int yy_is_interactive;

	/* Whether we're considered to be at the beginning of a line.
	 * If so, '^' rules will be active on the next match, otherwise
	 * not.
	 */
	int yy_at_bol;

    int yy_bs_lineno; /**< The line count. */
    int yy_bs_column; /**< The column count. */

	/* Whether to try to fill the input buffer when we reach the
	 * end of it.
	 */
	int yy_fill_buffer;

	int yy_buffer_status;

#define YY_BUFFER_NEW 0
#define YY_BUFFER_NORMAL 1
	/* When an EOF's been seen but there's still some text to process
	 * then we mark the buffer as YY_EOF_PENDING, to indicate that we
	 * shouldn't try reading from the input source any more.  We might
	 * still have a bunch of tokens to match, though, because of
	 * possible backing-up.
	 *
	 * When we actually see the EOF, we change the status to "new"
	 * (via yyrestart()), so that the user can continue scanning by
	 * just pointing yyin at a new input file.
	 */
#define YY_BUFFER_EOF_PENDING 2

	};
#endif /* !YY_STRUCT_YY_BUFFER_STATE */

/* Stack of input buffers. */
static size_t yy_buffer_stack_top = 0; /**< index of top of stack. */
static size_t yy_buffer_stack_max = 0; /**< capacity of stack. */
static YY_BUFFER_STATE * yy_buffer_stack = NULL; /**< Stack as an array. */

/* We provide macros for accessing buffer states in case in the
 * future we want to put the buffer states in a more general
 * "scanner state".
 *
 * Returns the top of the stack, or NULL.
 */
#define YY_CURRENT_BUFFER ( (yy_buffer_stack) \
                          ? (yy_buffer_stack)[(yy_buffer_stack_top)] \
                          : NULL)
/* Same as previous macro, but useful when we know that the buffer stack is not
 * NULL or when we need an lvalue. For internal use only.
 */
#define YY_CURRENT_BUFFER_LVALUE (yy_buffer_stack)[(yy_buffer_stack_top)]

/* yy_hold_char holds the character lost when yytext is formed. */
static char yy_hold_char;
static int yy_n_chars;		/* number of characters read into yy_ch_buf */
int yyleng;

/* Points to current character in buffer. */
static char *yy_c_buf_p = NULL;
static int yy_init = 0;		/* whether we need to initialize */
static int yy_start = 0;	/* start state number */

/* Flag which is used to allow yywrap()'s to do buffer switches
 * instead of setting up a fresh yyin.  A bit of a hack ...
 */
static int yy_did_buffer_switch_on_eof;

void yyrestart ( FILE *input_file  );
void yy_switch_to_buffer ( YY_BUFFER_STATE new_buffer  );
YY_BUFFER_STATE yy_create_buffer ( FILE *file, int size  );
void yy_delete_buffer ( YY_BUFFER_STATE b  );
void yy_flush_buffer ( YY_BUFFER_STATE b  );
void yypush_buffer_state ( YY_BUFFER_STATE new_buffer  );
void yypop_buffer_state ( void );

static void yyensure_buffer_stack ( void );
static void yy_load_buffer_state ( void );
static void yy_init_buffer ( YY_BUFFER_STATE b, FILE *file  );
#define YY_FLUSH_BUFFER yy_flush_buffer( YY_CURRENT_BUFFER )

YY_BUFFER_STATE yy_scan_buffer ( char *base, yy_size_t size  );
YY_BUFFER_STATE yy_scan_string ( const char *yy_str  );
YY_BUFFER_STATE yy_scan_bytes ( const char *bytes, int len  );

void *yyalloc ( yy_size_t  );
void *yyrealloc ( void *, yy_size_t  );
void yyfree ( void *  );

#define yy_new_buffer yy_create_buffer
#define yy_set_interactive(is_interactive) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){ \
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_is_interactive = is_interactive; \
	}
#define yy_set_bol(at_bol) \
	{ \
	if ( ! YY_CURRENT_BUFFER ){\
        yyensure_buffer_stack (); \
		YY_CURRENT_BUFFER_LVALUE =    \
            yy_create_buffer( yyin, YY_BUF_SIZE ); \
	} \
	YY_CURRENT_BUFFER_LVALUE->yy_at_bol = at_bol; \
	}
#define YY_AT_BOL() (YY_CURRENT_BUFFER_LVALUE->yy_at_bol)

/* Begin user sect3 */
typedef flex_uint8_t YY_CHAR;

FILE *yyin = NULL, *yyout = NULL;

typedef int yy_state_type;

extern int yylineno;
int yylineno = 1;

extern char *yytext;
#ifdef yytext_ptr
#undef yytext_ptr
#endif
#define yytext_ptr yytext

static yy_state_type yy_get_previous_state ( void );
static yy_state_type yy_try_NUL_trans ( yy_state_type current_state  );
static int yy_get_next_buffer ( void );
static void yynoreturn yy_fatal_error ( const char* msg  );

/* Done after the current pattern has been matched and before the
 * corresponding action - sets up yytext.
 */
#define YY_DO_BEFORE_ACTION \
	(yytext_ptr) = yy_bp; \
	yyleng = (int) (yy_cp - yy_bp); \
	(yy_hold_char) = *yy_cp; \
	*yy_cp = '\0'; \
	(yy_c_buf_p) = yy_cp;
#define YY_NUM_RULES 187
#define YY_END_OF_BUFFER 188
/* This struct is not used in this scanner,
   but its presence is necessary. */
struct yy_trans_info
	{
	flex_int32_t yy_verify;
	flex_int32_t yy_nxt;
	};
static const flex_int16_t yy_acclist[1344] =
    {   0,
      188,  186,  187,    3,  186,  187,    1,  187,   45,  186,
      187,  186,  187,   20,  186,  187,   40,  186,  187,   42,
      186,  187,  186,  187,   29,  186,  187,   30,  186,  187,
       38,  186,  187,   36,  186,  187,   69,  186,  187,   37,
      186,  187,   35,  186,  187,   39,  186,  187,  177,  186,
      187,  177,  186,  187,   32,  186,  187,   31,  186,  187,
       47,  186,  187,   46,  186,  187,   48,  186,  187,   34,
      186,  187,  186,  187,  113,  174,  186,  187,  113,  174,
      186,  187,  113,  174,  186,  187,  113,  174,  186,  187,
      113,  174,  186,  187,   25,  186,  187,  186,  187,   27,

      186,  187,   41,  186,  187,  113,  174,  186,  187,  113,
      174,  186,  187,  113,  174,  186,  187,  113,  174,  186,
      187,  113,  174,  186,  187,  113,  174,  186,  187,  113,
      174,  186,  187,  113,  174,  186,  187,  113,  174,  186,
      187,  113,  174,  186,  187,  113,  174,  186,  187,  113,
      174,  186,  187,  113,  174,  186,  187,  113,  174,  186,
      187,  113,  174,  186,  187,  113,  174,  186,  187,   21,
      186,  187,   43,  186,  187,   23,  186,  187,   44,  186,
      187,    3,    1,   62,  182,   53,   24,   65,   55,  180,
       51,   67,   49,   68,   50,   70,  178,    4,    6,   52,

      178,  176,  177,  177,  177,  177,   28,   22,   26,   57,
       63,   61,   64,   58,  185,  113,  174,  113,  174,  113,
      174,  113,  174,    2,   54,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  126,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  145,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,

      174,  113,  174,   56,   66,   33,  178,    6,  176,  177,
      176,  177,  179,  177,  177,  177,  175,   59,   60,  184,
      185,  113,  174,  113,  174,  183,  181,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  117,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,

      113,  174,  113,  174,  113,  174,  113,  143,  174,  113,
      174,  113,  174,  113,  147,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  178,  176,  177,  176,  177,  176,  177,  179,
      177,  175,  175,  113,  174,  113,  174,  113,  174,  109,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,

      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  118,  174,   99,  113,  174,
      113,  174,  113,  120,  174,  113,  121,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  128,  174,  113,
      129,  174,  113,  174,  113,  174,  113,  174,  113,  144,
      174,  113,  174,  113,  153,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  111,  113,  174,  113,

      174,  113,  174,  113,  174,  113,  171,  174,  113,  174,
      113,  174,   18,   13,  176,  177,  175,  175,  175,  110,
      113,  174,  113,  174,  113,  174,  113,  174,   98,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,   74,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      106,  113,  174,  113,  174,  113,  119,  174,  113,  123,

      174,  113,  174,  113,  174,  113,  174,  113,  174,  112,
      113,  174,  113,  131,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  157,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  169,  174,  113,  174,  113,  174,  113,  173,  174,
       15,  175,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,

      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  127,  174,  113,
      130,  174,  113,  146,  174,  113,  174,  113,  174,  113,
      156,  174,  113,  158,  174,  113,  161,  174,  113,  162,
      174,  113,  163,  174,  113,  167,  174,  113,  174,  113,
      174,  113,  174,  113,  174,   14,   16,    5,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,

      113,  174,   75,  113,  174,  113,  174,  101,  113,  174,
       79,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  148,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  114,  174,  113,
      174,  113,  125,  174,  113,  174,  113,  174,  113,  174,
      113,  168,  174,  113,  174,  113,  174,   12,  113,  174,
      113,  174,   78,  113,  174,  113,  115,  174,  113,  122,
      174,  113,  174,  113,  132,  174,  113,  133,  174,  113,
      134,  174,   85,  113,  174,  113,  174,  113,  174,  113,

      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,   83,  113,  174,
      113,  152,  174,  113,  174,   89,  113,  174,  113,  174,
      113,  159,  174,  113,  174,   95,  113,  174,  113,  174,
      113,  174,  113,  124,  174,  113,  154,  174,  113,  155,
      174,  113,  174,  113,  170,  174,  113,  172,  174,    8,
       11,   19,   17,  113,  174,  113,  174,  113,  135,  174,
      113,  136,  174,  113,  137,  174,   88,  113,  174,  113,
      174,   86,  113,  174,  113,  174,  113,  174,  113,  174,

      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  139,  174,  113,
      174,  113,  174,  113,  174,   84,  113,  174,  113,  174,
      113,  174,  104,  113,  174,  113,  174,  113,  151,  174,
      113,  174,  113,  174,    7,    8,  113,  174,  113,  174,
      113,  138,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  166,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  105,  113,  174,  113,
      140,  174,  113,  174,   82,  113,  174,  113,  150,  174,
       90,  113,  174,  113,  160,  174,   94,  113,  174,  113,

      174,   96,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,  113,  116,  174,   77,  113,  174,  113,  174,
      113,  174,  113,  174,  113,  149,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,  113,  174,  113,  174,  113,  174,  113,
      174,  113,  174,   91,  113,  174,   97,  113,  174,   92,
      113,  174,  113,  174,  113,  174,  113,  174,   93,  113,
      174,  113,  141,  174,  113,  142,  174,  113,  164,  174,
      113,  165,  174,   76,  113,  174,  103,   80,  113,  174,

       81,  113,  174,  113,  174,  113,  174,  113,  174,   71,
      113,  174,  113,  174,  113,  174,  113,  174,  113,  174,
      113,  174,   72,  107,  113,  174,  113,  174,   87,  113,
      174,  108,  113,  174,   73,    9,    9,   12,   10,   10,
       11,  102,  100
    } ;

static const flex_int16_t yy_accept[851] =
    {   0,
        1,    1,    1,    2,    4,    7,    9,   12,   14,   17,
       20,   23,   25,   28,   31,   34,   37,   40,   43,   46,
       49,   52,   55,   58,   61,   64,   67,   70,   73,   75,
       79,   83,   87,   91,   95,   98,  100,  103,  106,  110,
      114,  118,  122,  126,  130,  134,  138,  142,  146,  150,
      154,  158,  162,  166,  170,  173,  176,  179,  182,  183,
      184,  185,  185,  186,  186,  186,  186,  186,  186,  186,
      186,  187,  188,  189,  190,  190,  191,  191,  192,  193,
      194,  195,  196,  197,  197,  198,  199,  200,  201,  202,
      204,  205,  205,  206,  207,  207,  208,  209,  210,  211,

      212,  213,  214,  215,  215,  216,  218,  220,  222,  222,
      222,  224,  225,  226,  228,  230,  232,  234,  236,  238,
      240,  242,  244,  246,  248,  250,  252,  254,  256,  258,
      261,  263,  265,  267,  269,  271,  273,  275,  278,  280,
      282,  284,  286,  288,  290,  292,  294,  296,  298,  300,
      302,  304,  305,  306,  306,  306,  306,  306,  306,  306,
      306,  307,  307,  308,  308,  308,  309,  311,  313,  313,
      314,  315,  316,  317,  318,  319,  320,  320,  321,  321,
      322,  324,  326,  326,  327,  327,  327,  328,  328,  330,
      332,  334,  336,  338,  340,  342,  344,  346,  348,  350,

      352,  354,  356,  358,  360,  362,  364,  366,  368,  370,
      372,  374,  376,  378,  381,  383,  385,  387,  389,  391,
      393,  395,  397,  399,  401,  403,  405,  407,  410,  412,
      414,  417,  419,  421,  423,  425,  427,  429,  431,  433,
      435,  437,  439,  441,  443,  445,  447,  449,  451,  453,
      453,  453,  453,  453,  453,  453,  453,  453,  453,  453,
      453,  454,  454,  456,  458,  460,  461,  462,  463,  464,
      466,  468,  470,  473,  475,  477,  479,  481,  483,  485,
      487,  489,  491,  493,  495,  497,  499,  501,  503,  505,
      507,  509,  511,  513,  515,  517,  519,  521,  523,  525,

      527,  529,  531,  533,  535,  538,  541,  543,  546,  549,
      551,  553,  555,  557,  560,  563,  565,  567,  569,  572,
      574,  577,  579,  581,  583,  585,  587,  589,  591,  593,
      595,  597,  600,  602,  604,  606,  609,  611,  613,  613,
      614,  614,  614,  614,  614,  614,  615,  615,  615,  615,
      615,  615,  617,  618,  619,  620,  623,  625,  627,  629,
      632,  634,  636,  638,  640,  642,  644,  646,  648,  650,
      652,  655,  657,  659,  661,  663,  665,  667,  669,  671,
      673,  675,  677,  679,  681,  683,  685,  687,  689,  691,
      694,  696,  699,  702,  704,  706,  708,  710,  713,  716,

      718,  720,  722,  724,  727,  729,  731,  733,  735,  737,
      739,  741,  744,  746,  748,  751,  751,  751,  751,  752,
      752,  752,  752,  752,  752,  752,  752,  753,  755,  757,
      759,  761,  763,  765,  767,  769,  771,  773,  775,  777,
      779,  781,  781,  783,  785,  787,  789,  791,  793,  795,
      797,  799,  801,  803,  805,  807,  809,  811,  813,  815,
      817,  819,  821,  823,  825,  827,  830,  833,  836,  838,
      840,  843,  846,  849,  852,  855,  858,  860,  862,  864,
      866,  866,  866,  867,  867,  868,  868,  868,  868,  868,
      868,  869,  871,  873,  875,  877,  879,  881,  883,  885,

      887,  889,  891,  893,  895,  897,  899,  901,  903,  903,
      906,  908,  911,  914,  916,  918,  920,  922,  924,  926,
      928,  931,  933,  935,  937,  939,  941,  943,  945,  947,
      950,  952,  955,  957,  959,  961,  964,  966,  968,  968,
      968,  968,  968,  969,  969,  969,  969,  969,  969,  971,
      973,  976,  979,  982,  984,  987,  990,  993,  996,  998,
     1000, 1002, 1004, 1006, 1008, 1010, 1012, 1014, 1014, 1014,
     1016, 1018, 1020, 1022, 1024, 1026, 1028, 1031, 1034, 1036,
     1039, 1041, 1044, 1046, 1049, 1051, 1053, 1056, 1059, 1062,
     1064, 1064, 1067, 1070, 1071, 1071, 1071, 1071, 1071, 1071,

     1072, 1072, 1072, 1073, 1073, 1074, 1076, 1078, 1081, 1084,
     1087, 1090, 1092, 1095, 1097, 1099, 1101, 1103, 1105, 1107,
     1107, 1107, 1107, 1109, 1111, 1113, 1115, 1117, 1120, 1122,
     1124, 1126, 1129, 1131, 1133, 1136, 1138, 1141, 1143, 1145,
     1145, 1146, 1147, 1147, 1147, 1147, 1147, 1149, 1151, 1154,
     1156, 1158, 1160, 1162, 1165, 1167, 1169, 1171, 1171, 1171,
     1171, 1173, 1175, 1177, 1180, 1183, 1185, 1188, 1191, 1194,
     1197, 1200, 1202, 1205, 1207, 1207, 1207, 1207, 1207, 1207,
     1209, 1211, 1213, 1215, 1217, 1219, 1221, 1223, 1226, 1226,
     1226, 1226, 1229, 1229, 1229, 1231, 1233, 1235, 1238, 1240,

     1242, 1242, 1242, 1242, 1242, 1242, 1244, 1246, 1248, 1250,
     1252, 1254, 1256, 1258, 1258, 1258, 1258, 1260, 1260, 1260,
     1260, 1262, 1264, 1267, 1270, 1273, 1273, 1273, 1273, 1273,
     1273, 1275, 1277, 1279, 1282, 1285, 1288, 1291, 1294, 1294,
     1294, 1294, 1297, 1298, 1298, 1301, 1304, 1304, 1304, 1304,
     1304, 1304, 1306, 1308, 1310, 1311, 1311, 1311, 1311, 1311,
     1311, 1311, 1311, 1311, 1313, 1315, 1317, 1317, 1317, 1317,
     1317, 1317, 1317, 1317, 1317, 1319, 1321, 1323, 1323, 1324,
     1324, 1324, 1324, 1324, 1324, 1324, 1327, 1329, 1332, 1332,
     1332, 1332, 1332, 1332, 1332, 1332, 1335, 1335, 1335, 1335,

     1335, 1335, 1335, 1335, 1335, 1335, 1335, 1335, 1335, 1335,
     1335, 1336, 1336, 1336, 1336, 1336, 1336, 1336, 1336, 1336,
     1336, 1336, 1337, 1337, 1337, 1339, 1339, 1339, 1339, 1339,
     1339, 1339, 1340, 1340, 1340, 1342, 1342, 1342, 1342, 1343,
     1343, 1343, 1343, 1343, 1343, 1343, 1343, 1343, 1344, 1344
    } ;

static const YY_CHAR yy_ec[256] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    2,    3,
        4,    4,    4,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    5,    6,    7,    8,    1,    9,   10,   11,   12,
       13,   14,   15,   16,   17,   18,   19,   20,   21,   22,
       23,   24,   25,   26,   25,   27,   28,   29,   30,   31,
       32,   33,   34,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   43,   43,   45,   43,   46,   47,   43,
       43,   48,   49,   50,   51,   52,   43,   53,   43,   43,
       54,   55,   56,   57,   58,    1,   59,   60,   61,   62,

       63,   64,   65,   66,   67,   68,   69,   70,   71,   72,
       73,   74,   68,   75,   76,   77,   78,   79,   80,   81,
       82,   83,   84,   85,   86,   87,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,

        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1
    } ;

static const YY_CHAR yy_meta[88] =
    {   0,
        1,    2,    3,    1,    2,    1,    4,    1,    1,    1,
        1,    5,    1,    1,    1,    6,    1,    1,    1,    7,
        7,    7,    7,    7,    7,    7,    7,    7,    1,    1,
        1,    6,    1,    1,    1,    8,    8,    8,    8,    9,
        9,   10,   10,   10,   11,   10,   10,   10,   10,   10,
       10,   10,   10,    1,    1,    1,    1,   10,   12,   12,
       12,   12,   13,   13,   14,   14,   14,   14,   14,   15,
       14,   14,   14,   14,   14,   14,   14,   14,   14,   14,
       14,   14,   14,    1,    1,    1,    1
    } ;

static const flex_int16_t yy_base[881] =
    {   0,
        0,    0, 1518, 1519,   86,    0, 1485,   82,   87,   61,
       85,   85, 1519, 1519, 1484,   82, 1519,   83,   81,   99,
      144,  208, 1482, 1519,  101, 1482,   79, 1519, 1506,    0,
     1476, 1453,  112, 1462, 1519, 1506, 1519, 1476,   88,   65,
       47,   85,   79,   75,  104, 1434,   64, 1433, 1442,  113,
       73, 1432, 1430, 1436, 1519,  121, 1519, 1519,  171,    0,
     1519,  153, 1519, 1498,  217, 1437,  111, 1435, 1431, 1422,
     1519, 1519, 1519, 1519,  148, 1519, 1493, 1519, 1519, 1519,
     1519, 1519, 1519, 1477,  146,  180,    0, 1519,  206,  143,
        0,  240,  205,  147,    0, 1519, 1519, 1519, 1462, 1519,

     1519, 1519, 1461,  194,    0,    0, 1447, 1449,  197,  243,
     1439, 1519, 1519, 1419, 1415, 1414, 1416,  127, 1419,  258,
     1417, 1412, 1405, 1408, 1417, 1403, 1419, 1405, 1412, 1397,
     1398, 1395, 1395, 1401, 1397, 1394, 1391,    0,  142, 1395,
      208, 1393,  137,  140, 1398, 1389, 1385, 1388,  151,  207,
     1394, 1519, 1519,  267, 1396,  229, 1397,  277, 1386, 1398,
     1519,  330, 1519, 1425,    0,    0,  295,  153,  288,  354,
      228, 1519,  256,  315, 1519, 1519,  273, 1519, 1452,    0,
     1405,  253,  274, 1519, 1450,  247, 1519, 1449, 1411, 1383,
     1376, 1377, 1374,  228, 1376, 1370, 1374, 1391,  291,  269,

     1379, 1360,  289, 1368, 1366, 1363, 1374,  317, 1354, 1368,
     1361, 1407, 1367,    0, 1358, 1360, 1370, 1365, 1352,  247,
     1367, 1365, 1361, 1352, 1359, 1345, 1361,    0, 1346, 1351,
        0, 1352, 1349, 1338, 1336, 1338, 1340, 1348, 1333, 1331,
     1331, 1344, 1343, 1342, 1331, 1336, 1340, 1342, 1330, 1396,
     1331, 1333, 1333, 1328, 1391, 1330, 1330, 1328, 1325,  380,
      389, 1356,  292, 1519,  299, 1519, 1519,  374,  318, 1348,
     1341, 1342,    0, 1320, 1314, 1309, 1323, 1309, 1317, 1309,
     1315, 1304,  346, 1309, 1304, 1297, 1310, 1300, 1310, 1293,
     1293, 1295, 1292,  294, 1294, 1306, 1288, 1298, 1300, 1287,

     1288, 1289, 1334, 1285,    0,    0, 1287,    0,    0, 1278,
     1287, 1275, 1282,    0,    0, 1276, 1287, 1272,    0, 1276,
        0, 1271, 1271, 1270, 1267, 1280, 1269, 1274, 1279, 1278,
     1279,    0, 1275, 1264, 1270,    0, 1257, 1270, 1329, 1519,
     1259, 1325, 1326, 1264, 1324, 1519, 1262, 1262, 1319, 1252,
      384, 1519,  345, 1519,  327,    0, 1272, 1275, 1248,    0,
     1249, 1241, 1239, 1239,  332, 1256, 1255, 1240, 1242, 1246,
      424, 1235, 1248, 1232, 1237, 1243, 1228, 1245, 1242, 1235,
      401, 1229, 1235, 1222, 1226, 1236, 1233, 1218, 1235,    0,
     1220,    0,    0, 1220, 1221, 1227, 1217,    0,    0, 1225,

     1210, 1219, 1213,    0, 1222, 1219, 1221, 1204, 1214, 1217,
     1215,    0, 1205, 1209,    0, 1212, 1271, 1270, 1519, 1269,
      430, 1207,  440, 1211, 1255, 1249, 1519, 1241, 1216,  268,
     1202,  410, 1194, 1185, 1184, 1201, 1198, 1182, 1185, 1184,
     1184,  435, 1197, 1187, 1183, 1175, 1175, 1178, 1188, 1171,
     1184, 1174, 1223, 1220, 1165, 1171, 1166, 1177, 1180, 1165,
     1216, 1159, 1171, 1156, 1156,    0,    0,    0, 1169, 1170,
        0,    0,    0,    0,    0,    0, 1172, 1165, 1165, 1157,
     1221, 1222, 1519, 1221, 1519,  436,  440,  444,  449, 1218,
     1519, 1198, 1195, 1144, 1155, 1137,  425, 1195, 1192, 1145,

     1139, 1141, 1142, 1153,  432, 1140, 1150, 1135, 1134,  476,
     1146,    0,    0, 1131, 1128, 1144,  100, 1135, 1138, 1173,
        0, 1129, 1139, 1130, 1134, 1125, 1130, 1171, 1125,    0,
     1128,    0, 1115, 1112, 1118, 1182, 1124, 1122,    0, 1126,
     1180,  481, 1519,  445,  483,  487, 1179, 1178, 1122, 1155,
        0,    0,    0, 1151,    0, 1096, 1095,    0, 1103, 1098,
     1110, 1102, 1149, 1146, 1111, 1091, 1103, 1096,  491, 1087,
     1101, 1096, 1092, 1139, 1140, 1087, 1100, 1099, 1086,    0,
     1094, 1096, 1083, 1094, 1124, 1080,    0,    0,    0, 1076,
     1087,    0,    0, 1135, 1104,  476, 1087, 1141,  497, 1519,

      447, 1140, 1519, 1139, 1519, 1103, 1082, 1058,    0,    0,
        0, 1064,    0, 1064, 1055, 1054, 1057,  478, 1075, 1073,
     1073, 1057, 1052, 1067, 1054, 1056, 1098,    0, 1054, 1065,
     1045,    0, 1044, 1062,    0, 1061, 1060, 1054, 1055, 1049,
     1519, 1102, 1069,  453, 1070,  484, 1064, 1072,    0, 1046,
     1047, 1083, 1084,    0, 1083, 1080, 1045, 1025, 1022, 1030,
     1036,  504, 1026,    0,    0, 1030,    0,    0, 1038,    0,
        0, 1018, 1036, 1034, 1033, 1033,  454, 1046,  488, 1043,
     1041, 1026, 1027, 1027, 1026, 1025, 1024,    0, 1014, 1007,
     1020, 1020,  505, 1015, 1018, 1003, 1016,    0, 1015, 1002,

      996, 1021,  505, 1011,  508, 1019, 1021,  999,  995,  987,
      986,  985,  984,  990,  989,  981,  999,    0, 1043,  500,
      997,  991,    0,    0,    0, 1048, 1014,  512, 1002,  516,
     1000, 1000,  957,    0,    0,    0,    0,    0,  891,  894,
      885,    0, 1519,  507,    0,    0,  893,  914,  520,  911,
      519,  912,  897,  879, 1519,  858,  710,  508,  721,  732,
      521,  684,  522,  673,  667,  636,  630,  632,  514,  617,
      632,  525,  631,  526,  626,  629,  612,  603, 1519,  517,
      595,  588,  528,   52,  530,    0,  128,    0,  255,  521,
      333,  372,  534,  381,  533,    0,  477,  525,  463,  484,

      540,  496,  543,  489,  538,  481,  494,  550,  501,  557,
     1519,  548,  501,  582,  587,  506,  566,  562,  521,  583,
      585, 1519,  590,  591, 1519,  594,  601,  582,  541,  602,
      604, 1519,  606,  608, 1519,  599,  600,  538,  603,  541,
      555,  544,  543,  563,  545,  620,  622, 1519, 1519,  625,
      640,  655,  667,  676,  685,  700,  709,  722,  731,  746,
      761,  775,  790,  805,  820,  835,  850,  865,  873,  888,
      903,  918,  929,  943,  958,  973,  988, 1003, 1018, 1033
    } ;

static const flex_int16_t yy_def[881] =
    {   0,
      849,    1,  849,  849,  849,  850,  849,  851,  849,  849,
      849,  852,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  853,  854,
      854,  854,  854,  854,  849,  849,  849,  849,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  849,  849,  849,  849,  849,  850,
      849,  851,  849,  851,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  852,  849,  852,  849,  849,  849,
      849,  849,  849,  849,  855,  849,  856,  849,  855,   21,
       22,  849,  849,  849,  857,  849,  849,  849,  849,  849,

      849,  849,  849,  858,  859,  854,  854,  854,  860,  861,
      854,  849,  849,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  862,  856,  849,  849,  849,  849,
      849,  849,  849,  857,  849,  849,  858,  849,  858,  859,
      854,  854,  860,  849,  860,  861,  849,  861,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  863,
      849,  849,  849,  849,  864,  849,  849,  849,  849,  849,
      849,  862,  849,  849,  849,  849,  849,  849,  849,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  863,  849,
      849,  849,  865,  849,  864,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  849,  866,  865,  849,  867,
      849,  849,  849,  849,  849,  849,  849,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  849,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      849,  866,  849,  867,  849,  849,  868,  849,  849,  849,
      849,  854,  854,  854,  854,  854,  854,  854,  854,  854,

      854,  854,  854,  854,  854,  854,  854,  854,  849,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  869,  849,
      868,  868,  849,  868,  849,  870,  871,  872,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  849,  849,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      849,  854,  854,  873,  849,  868,  849,  870,  870,  849,

      870,  871,  849,  872,  849,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  849,
      849,  849,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  849,
      849,  873,  849,  868,  849,  870,  854,  854,  854,  854,
      854,  854,  854,  854,  854,  854,  854,  849,  849,  849,
      854,  854,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  854,  854,  854,  849,  849,  868,  849,  870,  854,
      854,  854,  854,  854,  854,  854,  854,  854,  849,  849,
      849,  854,  849,  874,  854,  854,  854,  854,  854,  854,

      849,  849,  868,  849,  870,  854,  854,  854,  854,  854,
      854,  854,  854,  849,  849,  849,  854,  874,  874,  874,
      854,  854,  854,  854,  854,  849,  849,  868,  849,  870,
      854,  854,  854,  854,  854,  854,  854,  854,  849,  849,
      849,  854,  849,  874,  854,  854,  849,  849,  868,  849,
      870,  854,  854,  854,  849,  849,  849,  874,  849,  849,
      868,  849,  870,  854,  854,  854,  849,  849,  874,  849,
      849,  868,  849,  870,  854,  854,  854,  849,  849,  874,
      849,  849,  868,  849,  870,  854,  854,  854,  849,  874,
      849,  849,  868,  849,  870,  854,  849,  874,  849,  849,

      868,  849,  870,  849,  874,  849,  849,  868,  849,  870,
      849,  874,  849,  875,  876,  849,  870,  874,  849,  875,
      875,  849,  876,  876,  849,  877,  878,  879,  849,  877,
      877,  849,  878,  878,  849,  879,  879,  849,  879,  849,
      849,  849,  849,  849,  849,  880,  880,  849,    0,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849
    } ;

static const flex_int16_t yy_nxt[1607] =
    {   0,
        4,    5,    6,    5,    5,    7,    8,    9,   10,   11,
       12,   13,   14,   15,   16,   17,   18,   19,   20,   21,
       22,   22,   22,   22,   22,   22,   22,   22,   23,   24,
       25,   26,   27,   28,   29,   30,   30,   30,   30,   30,
       31,   32,   30,   30,   33,   30,   30,   30,   30,   34,
       30,   30,   30,   35,   36,   37,   38,   39,   40,   41,
       42,   43,   44,   45,   46,   30,   47,   30,   30,   48,
       30,   30,   30,   30,   49,   50,   51,   52,   53,   54,
       30,   30,   30,   55,   56,   57,   58,   59,   63,   59,
       59,   65,   71,   72,   73,   76,   79,  794,   84,   81,

       85,   85,   85,   85,   85,   85,   85,   85,   85,   97,
      102,  103,   86,   80,   82,   83,   74,   87,  109,  124,
      574,  125,  110,  114,  115,  116,  575,  138,  117,   98,
       88,   99,  100,  118,  121,  139,   64,  119,  146,   77,
      122,  129,  123,  126,  131,  120,  132,  147,   66,   67,
      127,  130,  152,   68,  148,  133,   69,  128,   76,   63,
       70,   89,  134,   90,   90,   90,   90,   90,   90,   90,
       91,   91,   59,  135,   59,   59,  136,  796,  142,  143,
      156,  164,  157,   92,  164,  162,  163,  167,   93,  144,
      163,  173,  145,  168,   94,  849,   95,  265,  239,  194,

      178,  237,   77,  184,  195,  153,   92,   64,  162,  163,
      165,  230,  167,   93,  240,  163,  173,  245,  231,  238,
      168,   94,  265,  849,   95,   89,  246,   91,   91,   91,
       91,   91,   91,   91,   91,   91,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  162,  163,   92,  179,  171,
      163,  185,   93,  187,  169,  172,  169,  187,   94,  170,
      170,  170,  170,  170,  170,  170,  170,  170,  162,  163,
       92,  250,  233,  247,  171,  163,  248,   93,  172,  178,
      184,  255,  172,  234,  235,   94,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  252,  271,  188,  197,  278,

      267,  188,  279,  272,  253,  172,  198,  170,  170,  170,
      170,  170,  170,  170,  170,  170,  199,  797,  200,  201,
      202,  203,  310,  311,  204,  267,  494,  179,  185,  205,
      287,  206,  207,  208,  209,  210,  211,  212,  256,  263,
      495,  288,  264,  352,  260,  264,  260,  291,  257,  261,
      261,  261,  261,  261,  261,  261,  261,  261,  292,  268,
      284,  293,  355,  380,  263,  269,  285,  286,  352,  264,
      381,  427,  264,  170,  170,  170,  170,  170,  170,  170,
      170,  170,  368,  298,  268,  425,  369,  355,  425,  435,
      436,  799,  269,  299,  266,  354,  427,  426,  266,  261,

      261,  261,  261,  261,  261,  261,  261,  261,  261,  261,
      261,  261,  261,  261,  261,  261,  261,  266,  353,  800,
      802,  453,  354,  266,  354,  442,  454,  442,  442,  163,
      497,  486,  498,  163,  487,  499,  442,  486,  442,  442,
      486,  542,  543,  353,  542,  545,  554,  543,  546,  600,
      555,  354,  163,  547,  563,  543,  543,  564,  163,  489,
      489,  489,  489,  489,  489,  489,  489,  489,  489,  489,
      489,  489,  489,  489,  489,  489,  489,  569,  543,  569,
      569,  443,  542,  543,  545,  542,  600,  545,  599,  600,
      600,  599,  569,  540,  569,  569,  677,  544,  599,  600,

      655,  599,  596,  656,  646,  693,  693,  543,  693,  693,
      600,  703,  743,  509,  543,  694,  718,  644,  600,  743,
      743,  600,  543,  543,  600,  679,  743,  543,  600,  743,
      543,  705,  600,  743,  804,  600,  543,  743,  544,  806,
      597,  807,  543,  809,  601,  600,  811,  813,  621,  749,
      743,  814,  543,  728,  601,  761,  763,  774,  816,  600,
      743,  819,  744,  826,  751,  730,  772,  793,  600,  622,
      783,  785,  803,  828,  743,  795,  780,  790,  829,  798,
      758,  801,  769,  821,  822,  822,  821,  822,  824,  825,
      810,  824,  825,  825,  837,  831,  832,  808,  831,  838,

      812,  805,  834,  835,  832,  834,  832,  815,  835,  818,
      835,  837,  839,  840,  817,  839,  841,  842,  843,  844,
      845,  846,  848,  827,  848,   60,   60,  792,   60,   60,
       60,   60,   60,   60,   60,   60,   60,   60,   60,   60,
       62,   62,   62,   62,   62,   62,   62,   62,   62,   62,
       62,   62,   62,   62,   62,   75,   75,   75,   75,   75,
       75,   75,   75,   75,   75,   75,   75,   75,   75,   75,
      105,  791,  789,  788,  787,  786,  784,  782,  105,  105,
      105,  105,  106,  106,  106,  106,  106,  106,  106,  106,
      106,   85,  781,   85,  779,   85,  778,   85,  777,   85,

      166,  166,  776,  166,  166,  166,  166,  166,  166,  166,
      166,  166,  166,  166,  166,  174,  174,  174,  775,  773,
      174,  174,  177,  177,  177,  177,  177,  177,  177,  177,
      177,  177,  177,  177,  177,  177,  177,  180,  180,  180,
      180,  180,  180,  180,  180,  180,  183,  183,  183,  183,
      183,  183,  183,  183,  183,  183,  183,  183,  183,  183,
      183,  186,  186,  186,  186,  186,  186,  186,  186,  186,
      186,  186,  186,  186,  186,  186,  262,  771,  770,  768,
      262,  262,  262,  262,  262,  262,  262,  262,  262,  262,
      339,  339,  339,  339,  339,  339,  339,  339,  339,  339,

      339,  339,  339,  339,  339,  345,  345,  345,  345,  345,
      345,  345,  345,  345,  345,  345,  345,  345,  345,  345,
      418,  418,  418,  418,  418,  418,  418,  418,  418,  418,
      418,  418,  418,  418,  418,  482,  482,  482,  482,  482,
      482,  482,  482,  482,  482,  482,  482,  482,  482,  482,
      484,  484,  484,  484,  484,  484,  484,  484,  484,  484,
      484,  484,  484,  484,  484,  541,  541,  541,  541,  541,
      541,  541,  541,  541,  541,  541,  541,  541,  541,  541,
      594,  594,  594,  594,  594,  594,  594,  594,  598,  598,
      598,  598,  598,  598,  598,  598,  598,  598,  598,  598,

      598,  598,  598,  602,  602,  602,  602,  602,  602,  602,
      602,  602,  602,  602,  602,  602,  602,  602,  604,  604,
      604,  604,  604,  604,  604,  604,  604,  604,  604,  604,
      604,  604,  604,  642,  767,  642,  642,  642,  642,  642,
      642,  642,  642,  642,  719,  766,  765,  764,  762,  760,
      759,  757,  756,  755,  719,  719,  719,  719,  820,  820,
      820,  820,  820,  820,  820,  820,  820,  820,  820,  820,
      820,  820,  820,  823,  823,  823,  823,  823,  823,  823,
      823,  823,  823,  823,  823,  823,  823,  823,  830,  830,
      830,  830,  830,  830,  830,  830,  830,  830,  830,  830,

      830,  830,  830,  833,  833,  833,  833,  833,  833,  833,
      833,  833,  833,  833,  833,  833,  833,  833,  836,  836,
      754,  836,  836,  836,  836,  836,  836,  836,  836,  836,
      836,  836,  836,  847,  847,  847,  847,  847,  847,  847,
      847,  847,  847,  847,  847,  847,  847,  847,  753,  752,
      750,  748,  747,  746,  745,  743,  742,  741,  740,  739,
      738,  737,  736,  735,  734,  733,  732,  731,  729,  727,
      726,  725,  724,  723,  722,  721,  720,  717,  716,  715,
      714,  713,  712,  711,  710,  709,  708,  707,  706,  704,
      702,  701,  700,  699,  698,  697,  696,  695,  692,  691,

      690,  689,  688,  687,  686,  685,  684,  683,  682,  681,
      680,  678,  676,  641,  675,  674,  673,  672,  671,  670,
      669,  668,  667,  666,  665,  664,  663,  662,  661,  660,
      659,  658,  657,  654,  653,  652,  651,  650,  649,  648,
      647,  605,  603,  600,  645,  643,  641,  640,  639,  638,
      637,  636,  635,  634,  633,  632,  631,  630,  629,  628,
      627,  626,  625,  624,  623,  620,  619,  618,  617,  616,
      615,  614,  613,  612,  611,  610,  609,  608,  607,  606,
      605,  603,  543,  595,  593,  592,  591,  590,  589,  588,
      587,  586,  585,  584,  583,  582,  581,  580,  579,  578,

      577,  576,  573,  572,  571,  570,  568,  567,  566,  565,
      562,  561,  560,  559,  558,  557,  556,  553,  552,  551,
      550,  549,  548,  485,  483,  539,  538,  537,  536,  535,
      534,  533,  532,  531,  530,  529,  528,  527,  526,  525,
      524,  523,  522,  521,  520,  519,  518,  517,  516,  515,
      514,  513,  512,  511,  510,  508,  507,  506,  505,  504,
      503,  502,  501,  500,  496,  493,  492,  491,  426,  490,
      488,  485,  419,  483,  481,  480,  479,  478,  477,  476,
      475,  474,  473,  472,  471,  470,  469,  468,  467,  466,
      465,  464,  463,  462,  461,  460,  459,  458,  457,  456,

      455,  452,  451,  450,  449,  448,  447,  446,  445,  444,
      441,  440,  439,  438,  437,  434,  433,  432,  431,  430,
      429,  428,  424,  423,  422,  421,  346,  420,  419,  417,
      416,  340,  415,  414,  413,  412,  411,  410,  409,  408,
      407,  406,  405,  404,  403,  402,  401,  400,  399,  398,
      397,  396,  395,  394,  393,  392,  391,  390,  389,  388,
      387,  386,  385,  384,  383,  382,  379,  378,  377,  376,
      375,  374,  373,  372,  371,  370,  367,  366,  365,  364,
      363,  362,  361,  360,  359,  358,  357,  356,  351,  350,
      349,  348,  347,  346,  344,  343,  342,  341,  340,  338,

      337,  336,  335,  334,  333,  332,  331,  330,  329,  328,
      327,  326,  325,  324,  323,  322,  321,  320,  319,  318,
      317,  316,  315,  314,  313,  312,  309,  308,  307,  306,
      305,  304,  303,  302,  301,  300,  297,  296,  295,  294,
      290,  289,  283,  282,  281,  280,  277,  276,  275,  274,
      273,  849,  849,  270,  849,  165,  259,  258,  254,  251,
      249,  244,  243,  242,  241,  236,  232,  229,  228,  227,
      226,  225,  224,  223,  222,  221,  220,  219,  218,  217,
      216,  215,  214,  213,  196,  193,  192,  191,  190,  189,
      182,  181,  176,  175,  161,  849,  160,  159,  158,  155,

      849,  151,  150,  149,  141,  140,  137,  113,  112,  111,
      108,  107,  104,  101,   96,   78,   61,  849,    3,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,

      849,  849,  849,  849,  849,  849
    } ;

static const flex_int16_t yy_chk[1607] =
    {   0,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    1,    1,    1,
        1,    1,    1,    1,    1,    1,    1,    5,    8,    5,
        5,    9,   10,   10,   11,   12,   16,  784,   19,   18,

       19,   19,   19,   19,   19,   19,   19,   19,   19,   25,
       27,   27,   20,   16,   18,   18,   11,   20,   33,   41,
      517,   41,   33,   39,   39,   39,  517,   47,   39,   25,
       20,   25,   25,   39,   40,   47,    8,   39,   51,   12,
       40,   43,   40,   42,   44,   39,   44,   51,    9,    9,
       42,   43,   56,    9,   51,   44,    9,   42,   75,   62,
        9,   21,   45,   21,   21,   21,   21,   21,   21,   21,
       21,   21,   59,   45,   59,   59,   45,  787,   50,   50,
       67,   86,   67,   21,   86,   85,   85,   90,   21,   50,
       85,   94,   50,   90,   21,   90,   21,  168,  144,  118,

      104,  143,   75,  109,  118,   56,   21,   62,   85,   85,
       86,  139,   90,   21,  144,   85,   94,  149,  139,  143,
       90,   21,  168,   90,   21,   22,  149,   22,   22,   22,
       22,   22,   22,   22,   22,   22,   65,   65,   65,   65,
       65,   65,   65,   65,   65,   89,   89,   22,  104,   93,
       89,  109,   22,  110,   92,   93,   92,  186,   22,   92,
       92,   92,   92,   92,   92,   92,   92,   92,   89,   89,
       22,  154,  141,  150,   93,   89,  150,   22,  171,  177,
      183,  158,   93,  141,  141,   22,  154,  154,  154,  154,
      154,  154,  154,  154,  154,  156,  182,  110,  120,  194,

      173,  186,  194,  182,  156,  171,  120,  169,  169,  169,
      169,  169,  169,  169,  169,  169,  120,  789,  120,  120,
      120,  120,  220,  220,  120,  173,  430,  177,  183,  120,
      200,  120,  120,  120,  120,  120,  120,  120,  158,  167,
      430,  200,  263,  265,  162,  167,  162,  203,  158,  162,
      162,  162,  162,  162,  162,  162,  162,  162,  203,  174,
      199,  203,  269,  294,  167,  174,  199,  199,  265,  263,
      294,  355,  167,  170,  170,  170,  170,  170,  170,  170,
      170,  170,  283,  208,  174,  351,  283,  269,  351,  365,
      365,  791,  174,  208,  170,  353,  355,  351,  170,  260,

      260,  260,  260,  260,  260,  260,  260,  260,  261,  261,
      261,  261,  261,  261,  261,  261,  261,  170,  268,  792,
      794,  381,  353,  170,  268,  371,  381,  371,  371,  261,
      432,  421,  432,  261,  421,  432,  442,  486,  442,  442,
      486,  487,  487,  268,  487,  488,  497,  544,  488,  601,
      497,  268,  261,  489,  505,  644,  677,  505,  261,  423,
      423,  423,  423,  423,  423,  423,  423,  423,  489,  489,
      489,  489,  489,  489,  489,  489,  489,  510,  596,  510,
      510,  371,  542,  542,  545,  542,  646,  545,  546,  546,
      679,  546,  569,  486,  569,  569,  644,  487,  599,  599,

      618,  599,  544,  618,  601,  662,  693,  703,  662,  693,
      705,  677,  720,  442,  728,  662,  693,  596,  730,  744,
      758,  751,  749,  761,  763,  646,  769,  772,  774,  780,
      783,  679,  785,  790,  797,  795,  793,  798,  542,  799,
      545,  800,  801,  802,  546,  803,  804,  806,  569,  728,
      805,  807,  808,  703,  599,  749,  751,  763,  809,  810,
      812,  813,  720,  816,  730,  705,  761,  783,  817,  569,
      772,  774,  795,  818,  818,  785,  769,  780,  819,  790,
      744,  793,  758,  814,  814,  820,  814,  821,  815,  815,
      803,  815,  823,  824,  828,  826,  826,  801,  826,  829,

      805,  798,  827,  827,  830,  827,  831,  808,  833,  812,
      834,  836,  837,  838,  810,  839,  840,  841,  842,  843,
      844,  845,  846,  817,  847,  850,  850,  782,  850,  850,
      850,  850,  850,  850,  850,  850,  850,  850,  850,  850,
      851,  851,  851,  851,  851,  851,  851,  851,  851,  851,
      851,  851,  851,  851,  851,  852,  852,  852,  852,  852,
      852,  852,  852,  852,  852,  852,  852,  852,  852,  852,
      853,  781,  778,  777,  776,  775,  773,  771,  853,  853,
      853,  853,  854,  854,  854,  854,  854,  854,  854,  854,
      854,  855,  770,  855,  768,  855,  767,  855,  766,  855,

      856,  856,  765,  856,  856,  856,  856,  856,  856,  856,
      856,  856,  856,  856,  856,  857,  857,  857,  764,  762,
      857,  857,  858,  858,  858,  858,  858,  858,  858,  858,
      858,  858,  858,  858,  858,  858,  858,  859,  859,  859,
      859,  859,  859,  859,  859,  859,  860,  860,  860,  860,
      860,  860,  860,  860,  860,  860,  860,  860,  860,  860,
      860,  861,  861,  861,  861,  861,  861,  861,  861,  861,
      861,  861,  861,  861,  861,  861,  862,  760,  759,  757,
      862,  862,  862,  862,  862,  862,  862,  862,  862,  862,
      863,  863,  863,  863,  863,  863,  863,  863,  863,  863,

      863,  863,  863,  863,  863,  864,  864,  864,  864,  864,
      864,  864,  864,  864,  864,  864,  864,  864,  864,  864,
      865,  865,  865,  865,  865,  865,  865,  865,  865,  865,
      865,  865,  865,  865,  865,  866,  866,  866,  866,  866,
      866,  866,  866,  866,  866,  866,  866,  866,  866,  866,
      867,  867,  867,  867,  867,  867,  867,  867,  867,  867,
      867,  867,  867,  867,  867,  868,  868,  868,  868,  868,
      868,  868,  868,  868,  868,  868,  868,  868,  868,  868,
      869,  869,  869,  869,  869,  869,  869,  869,  870,  870,
      870,  870,  870,  870,  870,  870,  870,  870,  870,  870,

      870,  870,  870,  871,  871,  871,  871,  871,  871,  871,
      871,  871,  871,  871,  871,  871,  871,  871,  872,  872,
      872,  872,  872,  872,  872,  872,  872,  872,  872,  872,
      872,  872,  872,  873,  756,  873,  873,  873,  873,  873,
      873,  873,  873,  873,  874,  754,  753,  752,  750,  748,
      747,  741,  740,  739,  874,  874,  874,  874,  875,  875,
      875,  875,  875,  875,  875,  875,  875,  875,  875,  875,
      875,  875,  875,  876,  876,  876,  876,  876,  876,  876,
      876,  876,  876,  876,  876,  876,  876,  876,  877,  877,
      877,  877,  877,  877,  877,  877,  877,  877,  877,  877,

      877,  877,  877,  878,  878,  878,  878,  878,  878,  878,
      878,  878,  878,  878,  878,  878,  878,  878,  879,  879,
      733,  879,  879,  879,  879,  879,  879,  879,  879,  879,
      879,  879,  879,  880,  880,  880,  880,  880,  880,  880,
      880,  880,  880,  880,  880,  880,  880,  880,  732,  731,
      729,  727,  726,  722,  721,  719,  717,  716,  715,  714,
      713,  712,  711,  710,  709,  708,  707,  706,  704,  702,
      701,  700,  699,  697,  696,  695,  694,  692,  691,  690,
      689,  687,  686,  685,  684,  683,  682,  681,  680,  678,
      676,  675,  674,  673,  672,  669,  666,  663,  661,  660,

      659,  658,  657,  656,  655,  653,  652,  651,  650,  648,
      647,  645,  643,  642,  640,  639,  638,  637,  636,  634,
      633,  631,  630,  629,  627,  626,  625,  624,  623,  622,
      621,  620,  619,  617,  616,  615,  614,  612,  608,  607,
      606,  604,  602,  598,  597,  595,  594,  591,  590,  586,
      585,  584,  583,  582,  581,  579,  578,  577,  576,  575,
      574,  573,  572,  571,  570,  568,  567,  566,  565,  564,
      563,  562,  561,  560,  559,  557,  556,  554,  550,  549,
      548,  547,  541,  540,  538,  537,  536,  535,  534,  533,
      531,  529,  528,  527,  526,  525,  524,  523,  522,  520,

      519,  518,  516,  515,  514,  511,  509,  508,  507,  506,
      504,  503,  502,  501,  500,  499,  498,  496,  495,  494,
      493,  492,  490,  484,  482,  481,  480,  479,  478,  477,
      470,  469,  465,  464,  463,  462,  461,  460,  459,  458,
      457,  456,  455,  454,  453,  452,  451,  450,  449,  448,
      447,  446,  445,  444,  443,  441,  440,  439,  438,  437,
      436,  435,  434,  433,  431,  429,  428,  426,  425,  424,
      422,  420,  418,  417,  416,  414,  413,  411,  410,  409,
      408,  407,  406,  405,  403,  402,  401,  400,  397,  396,
      395,  394,  391,  389,  388,  387,  386,  385,  384,  383,

      382,  380,  379,  378,  377,  376,  375,  374,  373,  372,
      370,  369,  368,  367,  366,  364,  363,  362,  361,  359,
      358,  357,  350,  349,  348,  347,  345,  344,  343,  342,
      341,  339,  338,  337,  335,  334,  333,  331,  330,  329,
      328,  327,  326,  325,  324,  323,  322,  320,  318,  317,
      316,  313,  312,  311,  310,  307,  304,  303,  302,  301,
      300,  299,  298,  297,  296,  295,  293,  292,  291,  290,
      289,  288,  287,  286,  285,  284,  282,  281,  280,  279,
      278,  277,  276,  275,  274,  272,  271,  270,  262,  259,
      258,  257,  256,  255,  254,  253,  252,  251,  250,  249,

      248,  247,  246,  245,  244,  243,  242,  241,  240,  239,
      238,  237,  236,  235,  234,  233,  232,  230,  229,  227,
      226,  225,  224,  223,  222,  221,  219,  218,  217,  216,
      215,  213,  212,  211,  210,  209,  207,  206,  205,  204,
      202,  201,  198,  197,  196,  195,  193,  192,  191,  190,
      189,  188,  185,  181,  179,  164,  160,  159,  157,  155,
      151,  148,  147,  146,  145,  142,  140,  137,  136,  135,
      134,  133,  132,  131,  130,  129,  128,  127,  126,  125,
      124,  123,  122,  121,  119,  117,  116,  115,  114,  111,
      108,  107,  103,   99,   84,   77,   70,   69,   68,   66,

       64,   54,   53,   52,   49,   48,   46,   38,   36,   34,
       32,   31,   29,   26,   23,   15,    7,    3,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,
      849,  849,  849,  849,  849,  849,  849,  849,  849,  849,

      849,  849,  849,  849,  849,  849
    } ;

extern int yy_flex_debug;
int yy_flex_debug = 0;

static yy_state_type *yy_state_buf=0, *yy_state_ptr=0;
static char *yy_full_match;
static int yy_lp;
#define REJECT \
{ \
*yy_cp = (yy_hold_char); /* undo effects of setting up yytext */ \
yy_cp = (yy_full_match); /* restore poss. backed-over text */ \
++(yy_lp); \
goto find_rule; \
}

#define yymore() yymore_used_but_not_detected
#define YY_MORE_ADJ 0
#define YY_RESTORE_YY_MORE_OFFSET
char *yytext;
#line 1 "../gobject-introspection/giscanner/scannerlexer.l"
/* -*- Mode: C -*-
 * GObject introspection: C lexer
 *
 * Copyright (c) 1997 Sandro Sigala  <ssigala@globalnet.it>
 * Copyright (c) 2007-2008 Jürg Billeter  <j@bitron.ch>
 * Copyright (c) 2010 Andreas Rottmann <a.rottmann@gmx.at>
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
#line 32 "../gobject-introspection/giscanner/scannerlexer.l"
#include <ctype.h>
#include <stdio.h>
#include <string.h>
#ifndef _WIN32
#include <limits.h>
#else
#include <io.h>
#endif

#include <glib.h>
#include "sourcescanner.h"
#include "scannerparser.h"

int lineno;
char linebuf[2000];

#undef YY_BUF_SIZE
#define YY_BUF_SIZE 1048576

extern int yylex (GISourceScanner *scanner);
#define YY_DECL int yylex (GISourceScanner *scanner)
static int yywrap (void);
static void parse_comment (GISourceScanner *scanner);
static void parse_trigraph (GISourceScanner *scanner);
static void process_linemarks (GISourceScanner *scanner, gboolean has_line);
static int check_identifier (GISourceScanner *scanner, const char *);
static int parse_ignored_macro (void);
static void print_error (GISourceScanner *scanner);

#if (YY_FLEX_MAJOR_VERSION > 2) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION > 6)) \
  || ((YY_FLEX_MAJOR_VERSION == 2) && (YY_FLEX_MINOR_VERSION == 6) && (YY_FLEX_SUBMINOR_VERSION >= 1))
#define IS_EOF 0
#else
#define IS_EOF EOF
#endif

#line 1306 "giscanner/scannerlexer.c"
#line 1307 "giscanner/scannerlexer.c"

#define INITIAL 0

#ifndef YY_NO_UNISTD_H
/* Special case for "unistd.h", since it is non-ANSI. We include it way
 * down here because we want the user's section 1 to have been scanned first.
 * The user has a chance to override it with an option.
 */
#include <unistd.h>
#endif

#ifndef YY_EXTRA_TYPE
#define YY_EXTRA_TYPE void *
#endif

static int yy_init_globals ( void );

/* Accessor methods to globals.
   These are made visible to non-reentrant scanners for convenience. */

int yylex_destroy ( void );

int yyget_debug ( void );

void yyset_debug ( int debug_flag  );

YY_EXTRA_TYPE yyget_extra ( void );

void yyset_extra ( YY_EXTRA_TYPE user_defined  );

FILE *yyget_in ( void );

void yyset_in  ( FILE * _in_str  );

FILE *yyget_out ( void );

void yyset_out  ( FILE * _out_str  );

			int yyget_leng ( void );

char *yyget_text ( void );

int yyget_lineno ( void );

void yyset_lineno ( int _line_number  );

/* Macros after this point can all be overridden by user definitions in
 * section 1.
 */

#ifndef YY_SKIP_YYWRAP
#ifdef __cplusplus
extern "C" int yywrap ( void );
#else
extern int yywrap ( void );
#endif
#endif

#ifndef YY_NO_UNPUT
    
#endif

#ifndef yytext_ptr
static void yy_flex_strncpy ( char *, const char *, int );
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen ( const char * );
#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
static int yyinput ( void );
#else
static int input ( void );
#endif

#endif

/* Amount of stuff to slurp up with each read. */
#ifndef YY_READ_BUF_SIZE
#ifdef __ia64__
/* On IA-64, the buffer size is 16k, not 8k */
#define YY_READ_BUF_SIZE 16384
#else
#define YY_READ_BUF_SIZE 8192
#endif /* __ia64__ */
#endif

/* Copy whatever the last rule matched to the standard output. */
#ifndef ECHO
/* This used to be an fputs(), but since the string might contain NUL's,
 * we now use fwrite().
 */
#define ECHO do { if (fwrite( yytext, (size_t) yyleng, 1, yyout )) {} } while (0)
#endif

/* Gets input and stuffs it into "buf".  number of characters read, or YY_NULL,
 * is returned in "result".
 */
#ifndef YY_INPUT
#define YY_INPUT(buf,result,max_size) \
	if ( YY_CURRENT_BUFFER_LVALUE->yy_is_interactive ) \
		{ \
		int c = '*'; \
		int n; \
		for ( n = 0; n < max_size && \
			     (c = getc( yyin )) != EOF && c != '\n'; ++n ) \
			buf[n] = (char) c; \
		if ( c == '\n' ) \
			buf[n++] = (char) c; \
		if ( c == EOF && ferror( yyin ) ) \
			YY_FATAL_ERROR( "input in flex scanner failed" ); \
		result = n; \
		} \
	else \
		{ \
		errno=0; \
		while ( (result = (int) fread(buf, 1, (yy_size_t) max_size, yyin)) == 0 && ferror(yyin)) \
			{ \
			if( errno != EINTR) \
				{ \
				YY_FATAL_ERROR( "input in flex scanner failed" ); \
				break; \
				} \
			errno=0; \
			clearerr(yyin); \
			} \
		}\
\

#endif

/* No semi-colon after return; correct usage is to write "yyterminate();" -
 * we don't want an extra ';' after the "return" because that will cause
 * some compilers to complain about unreachable statements.
 */
#ifndef yyterminate
#define yyterminate() return YY_NULL
#endif

/* Number of entries by which start-condition stack grows. */
#ifndef YY_START_STACK_INCR
#define YY_START_STACK_INCR 25
#endif

/* Report a fatal error. */
#ifndef YY_FATAL_ERROR
#define YY_FATAL_ERROR(msg) yy_fatal_error( msg )
#endif

/* end tables serialization structures and prototypes */

/* Default declaration of generated scanner - a define so the user can
 * easily add parameters.
 */
#ifndef YY_DECL
#define YY_DECL_IS_OURS 1

extern int yylex (void);

#define YY_DECL int yylex (void)
#endif /* !YY_DECL */

/* Code executed at the beginning of each rule, after yytext and yyleng
 * have been set up.
 */
#ifndef YY_USER_ACTION
#define YY_USER_ACTION
#endif

/* Code executed at the end of each rule. */
#ifndef YY_BREAK
#define YY_BREAK /*LINTED*/break;
#endif

#define YY_RULE_SETUP \
	YY_USER_ACTION

/** The main scanner function which does all the work.
 */
YY_DECL
{
	yy_state_type yy_current_state;
	char *yy_cp, *yy_bp;
	int yy_act;
    
	if ( !(yy_init) )
		{
		(yy_init) = 1;

#ifdef YY_USER_INIT
		YY_USER_INIT;
#endif

        /* Create the reject buffer large enough to save one state per allowed character. */
        if ( ! (yy_state_buf) )
            (yy_state_buf) = (yy_state_type *)yyalloc(YY_STATE_BUF_SIZE  );
            if ( ! (yy_state_buf) )
                YY_FATAL_ERROR( "out of dynamic memory in yylex()" );

		if ( ! (yy_start) )
			(yy_start) = 1;	/* first start state */

		if ( ! yyin )
			yyin = stdin;

		if ( ! yyout )
			yyout = stdout;

		if ( ! YY_CURRENT_BUFFER ) {
			yyensure_buffer_stack ();
			YY_CURRENT_BUFFER_LVALUE =
				yy_create_buffer( yyin, YY_BUF_SIZE );
		}

		yy_load_buffer_state(  );
		}

	{
#line 80 "../gobject-introspection/giscanner/scannerlexer.l"


#line 1531 "giscanner/scannerlexer.c"

	while ( /*CONSTCOND*/1 )		/* loops until end-of-file is reached */
		{
		yy_cp = (yy_c_buf_p);

		/* Support of yytext. */
		*yy_cp = (yy_hold_char);

		/* yy_bp points to the position in yy_ch_buf of the start of
		 * the current run.
		 */
		yy_bp = yy_cp;

		yy_current_state = (yy_start);

		(yy_state_ptr) = (yy_state_buf);
		*(yy_state_ptr)++ = yy_current_state;

yy_match:
		do
			{
			YY_CHAR yy_c = yy_ec[YY_SC_TO_UI(*yy_cp)] ;
			while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
				{
				yy_current_state = (int) yy_def[yy_current_state];
				if ( yy_current_state >= 850 )
					yy_c = yy_meta[yy_c];
				}
			yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
			*(yy_state_ptr)++ = yy_current_state;
			++yy_cp;
			}
		while ( yy_base[yy_current_state] != 1519 );

yy_find_action:
		yy_current_state = *--(yy_state_ptr);
		(yy_lp) = yy_accept[yy_current_state];

find_rule: /* we branch to this label when backing up */

		for ( ; ; ) /* until we find what rule we matched */
			{
			if ( (yy_lp) && (yy_lp) < yy_accept[yy_current_state + 1] )
				{
				yy_act = yy_acclist[(yy_lp)];
					{
					(yy_full_match) = yy_cp;
					break;
					}
				}
			--yy_cp;
			yy_current_state = *--(yy_state_ptr);
			(yy_lp) = yy_accept[yy_current_state];
			}

		YY_DO_BEFORE_ACTION;

do_action:	/* This label is used only to access EOF actions. */

		switch ( yy_act )
	{ /* beginning of action switch */
case 1:
/* rule 1 can match eol */
YY_RULE_SETUP
#line 82 "../gobject-introspection/giscanner/scannerlexer.l"
{ strncpy(linebuf, yytext+1, sizeof(linebuf)); /* save the next line */
						linebuf[sizeof(linebuf)-1]='\0';
						/* printf("%4d:%s\n",lineno,linebuf); */
						yyless(1);      /* give back all but the \n to rescan */
						++lineno;
					}
	YY_BREAK
case 2:
/* rule 2 can match eol */
YY_RULE_SETUP
#line 88 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; }
	YY_BREAK
case 3:
YY_RULE_SETUP
#line 90 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore whitespace. */ }
	YY_BREAK
case 4:
YY_RULE_SETUP
#line 92 "../gobject-introspection/giscanner/scannerlexer.l"
{ parse_comment(scanner); }
	YY_BREAK
case 5:
YY_RULE_SETUP
#line 93 "../gobject-introspection/giscanner/scannerlexer.l"
{ parse_trigraph(scanner); }
	YY_BREAK
case 6:
YY_RULE_SETUP
#line 94 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore C++ style comments. */ }
	YY_BREAK
case 7:
YY_RULE_SETUP
#line 96 "../gobject-introspection/giscanner/scannerlexer.l"
{ yyless (yyleng - 1); return FUNCTION_MACRO; }
	YY_BREAK
case 8:
YY_RULE_SETUP
#line 97 "../gobject-introspection/giscanner/scannerlexer.l"
{ return OBJECT_MACRO; }
	YY_BREAK
case 9:
/* rule 9 can match eol */
YY_RULE_SETUP
#line 98 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_GI_SCANNER; }
	YY_BREAK
case 10:
/* rule 10 can match eol */
YY_RULE_SETUP
#line 99 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_GI_SCANNER; }
	YY_BREAK
case 11:
/* rule 11 can match eol */
YY_RULE_SETUP
#line 100 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return IFNDEF_COND; }
	YY_BREAK
case 12:
/* rule 12 can match eol */
YY_RULE_SETUP
#line 101 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return IFDEF_COND; }
	YY_BREAK
case 13:
/* rule 13 can match eol */
YY_RULE_SETUP
#line 102 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return IF_COND; }
	YY_BREAK
case 14:
/* rule 14 can match eol */
YY_RULE_SETUP
#line 103 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return ELIF_COND; }
	YY_BREAK
case 15:
/* rule 15 can match eol */
YY_RULE_SETUP
#line 104 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return ELSE_COND; }
	YY_BREAK
case 16:
/* rule 16 can match eol */
YY_RULE_SETUP
#line 105 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; return ENDIF_COND; }
	YY_BREAK
case 17:
/* rule 17 can match eol */
YY_RULE_SETUP
#line 106 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; /* Ignore pragma. */ }
	YY_BREAK
case 18:
/* rule 18 can match eol */
YY_RULE_SETUP
#line 108 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, FALSE); }
	YY_BREAK
case 19:
/* rule 19 can match eol */
YY_RULE_SETUP
#line 109 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; process_linemarks(scanner, TRUE); }
	YY_BREAK
case 20:
YY_RULE_SETUP
#line 110 "../gobject-introspection/giscanner/scannerlexer.l"
{ }
	YY_BREAK
case 21:
YY_RULE_SETUP
#line 111 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 22:
YY_RULE_SETUP
#line 112 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '{'; }
	YY_BREAK
case 23:
YY_RULE_SETUP
#line 113 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 24:
YY_RULE_SETUP
#line 114 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '}'; }
	YY_BREAK
case 25:
YY_RULE_SETUP
#line 115 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 26:
YY_RULE_SETUP
#line 116 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '['; }
	YY_BREAK
case 27:
YY_RULE_SETUP
#line 117 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 28:
YY_RULE_SETUP
#line 118 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ']'; }
	YY_BREAK
case 29:
YY_RULE_SETUP
#line 119 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '('; }
	YY_BREAK
case 30:
YY_RULE_SETUP
#line 120 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ')'; }
	YY_BREAK
case 31:
YY_RULE_SETUP
#line 121 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ';'; }
	YY_BREAK
case 32:
YY_RULE_SETUP
#line 122 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ':'; }
	YY_BREAK
case 33:
YY_RULE_SETUP
#line 123 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ELLIPSIS; }
	YY_BREAK
case 34:
YY_RULE_SETUP
#line 124 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '?'; }
	YY_BREAK
case 35:
YY_RULE_SETUP
#line 125 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '.'; }
	YY_BREAK
case 36:
YY_RULE_SETUP
#line 126 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '+'; }
	YY_BREAK
case 37:
YY_RULE_SETUP
#line 127 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '-'; }
	YY_BREAK
case 38:
YY_RULE_SETUP
#line 128 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '*'; }
	YY_BREAK
case 39:
YY_RULE_SETUP
#line 129 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '/'; }
	YY_BREAK
case 40:
YY_RULE_SETUP
#line 130 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '%'; }
	YY_BREAK
case 41:
YY_RULE_SETUP
#line 131 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '^'; }
	YY_BREAK
case 42:
YY_RULE_SETUP
#line 132 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '&'; }
	YY_BREAK
case 43:
YY_RULE_SETUP
#line 133 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '|'; }
	YY_BREAK
case 44:
YY_RULE_SETUP
#line 134 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '~'; }
	YY_BREAK
case 45:
YY_RULE_SETUP
#line 135 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '!'; }
	YY_BREAK
case 46:
YY_RULE_SETUP
#line 136 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '='; }
	YY_BREAK
case 47:
YY_RULE_SETUP
#line 137 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '<'; }
	YY_BREAK
case 48:
YY_RULE_SETUP
#line 138 "../gobject-introspection/giscanner/scannerlexer.l"
{ return '>'; }
	YY_BREAK
case 49:
YY_RULE_SETUP
#line 139 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ADDEQ; }
	YY_BREAK
case 50:
YY_RULE_SETUP
#line 140 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SUBEQ; }
	YY_BREAK
case 51:
YY_RULE_SETUP
#line 141 "../gobject-introspection/giscanner/scannerlexer.l"
{ return MULEQ; }
	YY_BREAK
case 52:
YY_RULE_SETUP
#line 142 "../gobject-introspection/giscanner/scannerlexer.l"
{ return DIVEQ; }
	YY_BREAK
case 53:
YY_RULE_SETUP
#line 143 "../gobject-introspection/giscanner/scannerlexer.l"
{ return MODEQ; }
	YY_BREAK
case 54:
YY_RULE_SETUP
#line 144 "../gobject-introspection/giscanner/scannerlexer.l"
{ return XOREQ; }
	YY_BREAK
case 55:
YY_RULE_SETUP
#line 145 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ANDEQ; }
	YY_BREAK
case 56:
YY_RULE_SETUP
#line 146 "../gobject-introspection/giscanner/scannerlexer.l"
{ return OREQ; }
	YY_BREAK
case 57:
YY_RULE_SETUP
#line 147 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SL; }
	YY_BREAK
case 58:
YY_RULE_SETUP
#line 148 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SR; }
	YY_BREAK
case 59:
YY_RULE_SETUP
#line 149 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SLEQ; }
	YY_BREAK
case 60:
YY_RULE_SETUP
#line 150 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SREQ; }
	YY_BREAK
case 61:
YY_RULE_SETUP
#line 151 "../gobject-introspection/giscanner/scannerlexer.l"
{ return EQ; }
	YY_BREAK
case 62:
YY_RULE_SETUP
#line 152 "../gobject-introspection/giscanner/scannerlexer.l"
{ return NOTEQ; }
	YY_BREAK
case 63:
YY_RULE_SETUP
#line 153 "../gobject-introspection/giscanner/scannerlexer.l"
{ return LTEQ; }
	YY_BREAK
case 64:
YY_RULE_SETUP
#line 154 "../gobject-introspection/giscanner/scannerlexer.l"
{ return GTEQ; }
	YY_BREAK
case 65:
YY_RULE_SETUP
#line 155 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ANDAND; }
	YY_BREAK
case 66:
YY_RULE_SETUP
#line 156 "../gobject-introspection/giscanner/scannerlexer.l"
{ return OROR; }
	YY_BREAK
case 67:
YY_RULE_SETUP
#line 157 "../gobject-introspection/giscanner/scannerlexer.l"
{ return PLUSPLUS; }
	YY_BREAK
case 68:
YY_RULE_SETUP
#line 158 "../gobject-introspection/giscanner/scannerlexer.l"
{ return MINUSMINUS; }
	YY_BREAK
case 69:
YY_RULE_SETUP
#line 159 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ','; }
	YY_BREAK
case 70:
YY_RULE_SETUP
#line 160 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ARROW; }
	YY_BREAK
case 71:
YY_RULE_SETUP
#line 162 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 72:
YY_RULE_SETUP
#line 163 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 73:
YY_RULE_SETUP
#line 164 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 74:
YY_RULE_SETUP
#line 165 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 75:
YY_RULE_SETUP
#line 166 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 76:
YY_RULE_SETUP
#line 167 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 77:
YY_RULE_SETUP
#line 168 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 78:
YY_RULE_SETUP
#line 169 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 79:
YY_RULE_SETUP
#line 170 "../gobject-introspection/giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 80:
YY_RULE_SETUP
#line 171 "../gobject-introspection/giscanner/scannerlexer.l"
{ return EXTENSION; }
	YY_BREAK
case 81:
YY_RULE_SETUP
#line 172 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 82:
YY_RULE_SETUP
#line 173 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 83:
YY_RULE_SETUP
#line 174 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 84:
YY_RULE_SETUP
#line 175 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 85:
YY_RULE_SETUP
#line 176 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 86:
YY_RULE_SETUP
#line 177 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 87:
YY_RULE_SETUP
#line 178 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 88:
YY_RULE_SETUP
#line 179 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 89:
YY_RULE_SETUP
#line 180 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 90:
YY_RULE_SETUP
#line 181 "../gobject-introspection/giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 91:
YY_RULE_SETUP
#line 182 "../gobject-introspection/giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 92:
YY_RULE_SETUP
#line 183 "../gobject-introspection/giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 93:
YY_RULE_SETUP
#line 184 "../gobject-introspection/giscanner/scannerlexer.l"
{ return THREAD_LOCAL; }
	YY_BREAK
case 94:
YY_RULE_SETUP
#line 185 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (parse_ignored_macro()) return VOID; else REJECT; }
	YY_BREAK
case 95:
YY_RULE_SETUP
#line 186 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (parse_ignored_macro()) return VOID; else REJECT; }
	YY_BREAK
case 96:
YY_RULE_SETUP
#line 187 "../gobject-introspection/giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 97:
YY_RULE_SETUP
#line 188 "../gobject-introspection/giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 98:
YY_RULE_SETUP
#line 189 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 99:
YY_RULE_SETUP
#line 190 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 100:
/* rule 100 can match eol */
YY_RULE_SETUP
#line 191 "../gobject-introspection/giscanner/scannerlexer.l"
{ ++lineno; /* Ignore */ }
	YY_BREAK
case 101:
YY_RULE_SETUP
#line 192 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 102:
YY_RULE_SETUP
#line 193 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 103:
YY_RULE_SETUP
#line 194 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* Ignore */ }
	YY_BREAK
case 104:
YY_RULE_SETUP
#line 195 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 105:
YY_RULE_SETUP
#line 196 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 106:
YY_RULE_SETUP
#line 197 "../gobject-introspection/giscanner/scannerlexer.l"
{ /* ignore */ }
	YY_BREAK
case 107:
YY_RULE_SETUP
#line 199 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INTL_CONST; }
	YY_BREAK
case 108:
YY_RULE_SETUP
#line 200 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INTUL_CONST; }
	YY_BREAK
case 109:
YY_RULE_SETUP
#line 202 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 110:
YY_RULE_SETUP
#line 203 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 111:
YY_RULE_SETUP
#line 204 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 112:
YY_RULE_SETUP
#line 205 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BOOLEAN; }
	YY_BREAK
case 113:
YY_RULE_SETUP
#line 207 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (scanner->macro_scan) return check_identifier(scanner, yytext); else REJECT; }
	YY_BREAK
case 114:
YY_RULE_SETUP
#line 209 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ALIGNOF; }
	YY_BREAK
case 115:
YY_RULE_SETUP
#line 210 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ALIGNOF; }
	YY_BREAK
case 116:
YY_RULE_SETUP
#line 211 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ALIGNOF; }
	YY_BREAK
case 117:
YY_RULE_SETUP
#line 212 "../gobject-introspection/giscanner/scannerlexer.l"
{ if (!parse_ignored_macro()) REJECT; }
	YY_BREAK
case 118:
YY_RULE_SETUP
#line 213 "../gobject-introspection/giscanner/scannerlexer.l"
{ return AUTO; }
	YY_BREAK
case 119:
YY_RULE_SETUP
#line 214 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BREAK; }
	YY_BREAK
case 120:
YY_RULE_SETUP
#line 215 "../gobject-introspection/giscanner/scannerlexer.l"
{ return CASE; }
	YY_BREAK
case 121:
YY_RULE_SETUP
#line 216 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 122:
YY_RULE_SETUP
#line 217 "../gobject-introspection/giscanner/scannerlexer.l"
{ return COMPLEX; }
	YY_BREAK
case 123:
YY_RULE_SETUP
#line 218 "../gobject-introspection/giscanner/scannerlexer.l"
{ return CONST; }
	YY_BREAK
case 124:
YY_RULE_SETUP
#line 219 "../gobject-introspection/giscanner/scannerlexer.l"
{ return CONTINUE; }
	YY_BREAK
case 125:
YY_RULE_SETUP
#line 220 "../gobject-introspection/giscanner/scannerlexer.l"
{ return DEFAULT; }
	YY_BREAK
case 126:
YY_RULE_SETUP
#line 221 "../gobject-introspection/giscanner/scannerlexer.l"
{ return DO; }
	YY_BREAK
case 127:
YY_RULE_SETUP
#line 222 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 128:
YY_RULE_SETUP
#line 223 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ELSE; }
	YY_BREAK
case 129:
YY_RULE_SETUP
#line 224 "../gobject-introspection/giscanner/scannerlexer.l"
{ return ENUM; }
	YY_BREAK
case 130:
YY_RULE_SETUP
#line 225 "../gobject-introspection/giscanner/scannerlexer.l"
{ return EXTERN; }
	YY_BREAK
case 131:
YY_RULE_SETUP
#line 226 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 132:
YY_RULE_SETUP
#line 227 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 133:
YY_RULE_SETUP
#line 228 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 134:
YY_RULE_SETUP
#line 229 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 135:
YY_RULE_SETUP
#line 230 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 136:
YY_RULE_SETUP
#line 231 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 137:
YY_RULE_SETUP
#line 232 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 138:
YY_RULE_SETUP
#line 233 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 139:
YY_RULE_SETUP
#line 234 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 140:
YY_RULE_SETUP
#line 235 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 141:
YY_RULE_SETUP
#line 236 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 142:
YY_RULE_SETUP
#line 237 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 143:
YY_RULE_SETUP
#line 238 "../gobject-introspection/giscanner/scannerlexer.l"
{ return FOR; }
	YY_BREAK
case 144:
YY_RULE_SETUP
#line 239 "../gobject-introspection/giscanner/scannerlexer.l"
{ return GOTO; }
	YY_BREAK
case 145:
YY_RULE_SETUP
#line 240 "../gobject-introspection/giscanner/scannerlexer.l"
{ return IF; }
	YY_BREAK
case 146:
YY_RULE_SETUP
#line 241 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INLINE; }
	YY_BREAK
case 147:
YY_RULE_SETUP
#line 242 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 148:
YY_RULE_SETUP
#line 243 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 149:
YY_RULE_SETUP
#line 244 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 150:
YY_RULE_SETUP
#line 245 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 151:
YY_RULE_SETUP
#line 246 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 152:
YY_RULE_SETUP
#line 247 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 153:
YY_RULE_SETUP
#line 248 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 154:
YY_RULE_SETUP
#line 249 "../gobject-introspection/giscanner/scannerlexer.l"
{ return REGISTER; }
	YY_BREAK
case 155:
YY_RULE_SETUP
#line 250 "../gobject-introspection/giscanner/scannerlexer.l"
{ return RESTRICT; }
	YY_BREAK
case 156:
YY_RULE_SETUP
#line 251 "../gobject-introspection/giscanner/scannerlexer.l"
{ return RETURN; }
	YY_BREAK
case 157:
YY_RULE_SETUP
#line 252 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 158:
YY_RULE_SETUP
#line 253 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 159:
YY_RULE_SETUP
#line 254 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 160:
YY_RULE_SETUP
#line 255 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SIGNED; }
	YY_BREAK
case 161:
YY_RULE_SETUP
#line 256 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SIZEOF; }
	YY_BREAK
case 162:
YY_RULE_SETUP
#line 257 "../gobject-introspection/giscanner/scannerlexer.l"
{ return STATIC; }
	YY_BREAK
case 163:
YY_RULE_SETUP
#line 258 "../gobject-introspection/giscanner/scannerlexer.l"
{ return STRUCT; }
	YY_BREAK
case 164:
YY_RULE_SETUP
#line 259 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 165:
YY_RULE_SETUP
#line 260 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 166:
YY_RULE_SETUP
#line 261 "../gobject-introspection/giscanner/scannerlexer.l"
{ return BASIC_TYPE; }
	YY_BREAK
case 167:
YY_RULE_SETUP
#line 262 "../gobject-introspection/giscanner/scannerlexer.l"
{ return SWITCH; }
	YY_BREAK
case 168:
YY_RULE_SETUP
#line 263 "../gobject-introspection/giscanner/scannerlexer.l"
{ return TYPEDEF; }
	YY_BREAK
case 169:
YY_RULE_SETUP
#line 264 "../gobject-introspection/giscanner/scannerlexer.l"
{ return UNION; }
	YY_BREAK
case 170:
YY_RULE_SETUP
#line 265 "../gobject-introspection/giscanner/scannerlexer.l"
{ return UNSIGNED; }
	YY_BREAK
case 171:
YY_RULE_SETUP
#line 266 "../gobject-introspection/giscanner/scannerlexer.l"
{ return VOID; }
	YY_BREAK
case 172:
YY_RULE_SETUP
#line 267 "../gobject-introspection/giscanner/scannerlexer.l"
{ return VOLATILE; }
	YY_BREAK
case 173:
YY_RULE_SETUP
#line 268 "../gobject-introspection/giscanner/scannerlexer.l"
{ return WHILE; }
	YY_BREAK
case 174:
YY_RULE_SETUP
#line 270 "../gobject-introspection/giscanner/scannerlexer.l"
{ return check_identifier(scanner, yytext); }
	YY_BREAK
case 175:
YY_RULE_SETUP
#line 272 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 176:
YY_RULE_SETUP
#line 273 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 177:
YY_RULE_SETUP
#line 274 "../gobject-introspection/giscanner/scannerlexer.l"
{ return INTEGER; }
	YY_BREAK
case 178:
YY_RULE_SETUP
#line 276 "../gobject-introspection/giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 179:
YY_RULE_SETUP
#line 277 "../gobject-introspection/giscanner/scannerlexer.l"
{ return FLOATING; }
	YY_BREAK
case 180:
/* rule 180 can match eol */
YY_RULE_SETUP
#line 279 "../gobject-introspection/giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 181:
/* rule 181 can match eol */
YY_RULE_SETUP
#line 280 "../gobject-introspection/giscanner/scannerlexer.l"
{ return CHARACTER; }
	YY_BREAK
case 182:
/* rule 182 can match eol */
YY_RULE_SETUP
#line 282 "../gobject-introspection/giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 183:
/* rule 183 can match eol */
YY_RULE_SETUP
#line 283 "../gobject-introspection/giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 184:
/* rule 184 can match eol */
YY_RULE_SETUP
#line 284 "../gobject-introspection/giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 185:
YY_RULE_SETUP
#line 285 "../gobject-introspection/giscanner/scannerlexer.l"
{ return STRING; }
	YY_BREAK
case 186:
YY_RULE_SETUP
#line 287 "../gobject-introspection/giscanner/scannerlexer.l"
{ print_error(scanner); }
	YY_BREAK
case 187:
YY_RULE_SETUP
#line 289 "../gobject-introspection/giscanner/scannerlexer.l"
ECHO;
	YY_BREAK
#line 2552 "giscanner/scannerlexer.c"
			case YY_STATE_EOF(INITIAL):
				yyterminate();

	case YY_END_OF_BUFFER:
		{
		/* Amount of text matched not including the EOB char. */
		int yy_amount_of_matched_text = (int) (yy_cp - (yytext_ptr)) - 1;

		/* Undo the effects of YY_DO_BEFORE_ACTION. */
		*yy_cp = (yy_hold_char);
		YY_RESTORE_YY_MORE_OFFSET

		if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_NEW )
			{
			/* We're scanning a new file or input source.  It's
			 * possible that this happened because the user
			 * just pointed yyin at a new source and called
			 * yylex().  If so, then we have to assure
			 * consistency between YY_CURRENT_BUFFER and our
			 * globals.  Here is the right place to do so, because
			 * this is the first action (other than possibly a
			 * back-up) that will match for the new input source.
			 */
			(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
			YY_CURRENT_BUFFER_LVALUE->yy_input_file = yyin;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status = YY_BUFFER_NORMAL;
			}

		/* Note that here we test for yy_c_buf_p "<=" to the position
		 * of the first EOB in the buffer, since yy_c_buf_p will
		 * already have been incremented past the NUL character
		 * (since all states make transitions on EOB to the
		 * end-of-buffer state).  Contrast this with the test
		 * in input().
		 */
		if ( (yy_c_buf_p) <= &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			{ /* This was really a NUL. */
			yy_state_type yy_next_state;

			(yy_c_buf_p) = (yytext_ptr) + yy_amount_of_matched_text;

			yy_current_state = yy_get_previous_state(  );

			/* Okay, we're now positioned to make the NUL
			 * transition.  We couldn't have
			 * yy_get_previous_state() go ahead and do it
			 * for us because it doesn't know how to deal
			 * with the possibility of jamming (and we don't
			 * want to build jamming into it because then it
			 * will run more slowly).
			 */

			yy_next_state = yy_try_NUL_trans( yy_current_state );

			yy_bp = (yytext_ptr) + YY_MORE_ADJ;

			if ( yy_next_state )
				{
				/* Consume the NUL. */
				yy_cp = ++(yy_c_buf_p);
				yy_current_state = yy_next_state;
				goto yy_match;
				}

			else
				{
				yy_cp = (yy_c_buf_p);
				goto yy_find_action;
				}
			}

		else switch ( yy_get_next_buffer(  ) )
			{
			case EOB_ACT_END_OF_FILE:
				{
				(yy_did_buffer_switch_on_eof) = 0;

				if ( yywrap(  ) )
					{
					/* Note: because we've taken care in
					 * yy_get_next_buffer() to have set up
					 * yytext, we can now set up
					 * yy_c_buf_p so that if some total
					 * hoser (like flex itself) wants to
					 * call the scanner after we return the
					 * YY_NULL, it'll still work - another
					 * YY_NULL will get returned.
					 */
					(yy_c_buf_p) = (yytext_ptr) + YY_MORE_ADJ;

					yy_act = YY_STATE_EOF(YY_START);
					goto do_action;
					}

				else
					{
					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
					}
				break;
				}

			case EOB_ACT_CONTINUE_SCAN:
				(yy_c_buf_p) =
					(yytext_ptr) + yy_amount_of_matched_text;

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_match;

			case EOB_ACT_LAST_MATCH:
				(yy_c_buf_p) =
				&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)];

				yy_current_state = yy_get_previous_state(  );

				yy_cp = (yy_c_buf_p);
				yy_bp = (yytext_ptr) + YY_MORE_ADJ;
				goto yy_find_action;
			}
		break;
		}

	default:
		YY_FATAL_ERROR(
			"fatal flex scanner internal error--no action found" );
	} /* end of action switch */
		} /* end of scanning one token */
	} /* end of user's declarations */
} /* end of yylex */

/* yy_get_next_buffer - try to read in a new buffer
 *
 * Returns a code representing an action:
 *	EOB_ACT_LAST_MATCH -
 *	EOB_ACT_CONTINUE_SCAN - continue scanning from current position
 *	EOB_ACT_END_OF_FILE - end of file
 */
static int yy_get_next_buffer (void)
{
    	char *dest = YY_CURRENT_BUFFER_LVALUE->yy_ch_buf;
	char *source = (yytext_ptr);
	int number_to_move, i;
	int ret_val;

	if ( (yy_c_buf_p) > &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] )
		YY_FATAL_ERROR(
		"fatal flex scanner internal error--end of buffer missed" );

	if ( YY_CURRENT_BUFFER_LVALUE->yy_fill_buffer == 0 )
		{ /* Don't try to fill the buffer, so this is an EOF. */
		if ( (yy_c_buf_p) - (yytext_ptr) - YY_MORE_ADJ == 1 )
			{
			/* We matched a single character, the EOB, so
			 * treat this as a final EOF.
			 */
			return EOB_ACT_END_OF_FILE;
			}

		else
			{
			/* We matched some text prior to the EOB, first
			 * process it.
			 */
			return EOB_ACT_LAST_MATCH;
			}
		}

	/* Try to read more data. */

	/* First move last chars to start of buffer. */
	number_to_move = (int) ((yy_c_buf_p) - (yytext_ptr) - 1);

	for ( i = 0; i < number_to_move; ++i )
		*(dest++) = *(source++);

	if ( YY_CURRENT_BUFFER_LVALUE->yy_buffer_status == YY_BUFFER_EOF_PENDING )
		/* don't do the read, it's not guaranteed to return an EOF,
		 * just force an EOF
		 */
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars) = 0;

	else
		{
			int num_to_read =
			YY_CURRENT_BUFFER_LVALUE->yy_buf_size - number_to_move - 1;

		while ( num_to_read <= 0 )
			{ /* Not enough room in the buffer - grow it. */

			YY_FATAL_ERROR(
"input buffer overflow, can't enlarge buffer because scanner uses REJECT" );

			}

		if ( num_to_read > YY_READ_BUF_SIZE )
			num_to_read = YY_READ_BUF_SIZE;

		/* Read in more data. */
		YY_INPUT( (&YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[number_to_move]),
			(yy_n_chars), num_to_read );

		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	if ( (yy_n_chars) == 0 )
		{
		if ( number_to_move == YY_MORE_ADJ )
			{
			ret_val = EOB_ACT_END_OF_FILE;
			yyrestart( yyin  );
			}

		else
			{
			ret_val = EOB_ACT_LAST_MATCH;
			YY_CURRENT_BUFFER_LVALUE->yy_buffer_status =
				YY_BUFFER_EOF_PENDING;
			}
		}

	else
		ret_val = EOB_ACT_CONTINUE_SCAN;

	if (((yy_n_chars) + number_to_move) > YY_CURRENT_BUFFER_LVALUE->yy_buf_size) {
		/* Extend the array by 50%, plus the number we really need. */
		int new_size = (yy_n_chars) + number_to_move + ((yy_n_chars) >> 1);
		YY_CURRENT_BUFFER_LVALUE->yy_ch_buf = (char *) yyrealloc(
			(void *) YY_CURRENT_BUFFER_LVALUE->yy_ch_buf, (yy_size_t) new_size  );
		if ( ! YY_CURRENT_BUFFER_LVALUE->yy_ch_buf )
			YY_FATAL_ERROR( "out of dynamic memory in yy_get_next_buffer()" );
		/* "- 2" to take care of EOB's */
		YY_CURRENT_BUFFER_LVALUE->yy_buf_size = (int) (new_size - 2);
	}

	(yy_n_chars) += number_to_move;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] = YY_END_OF_BUFFER_CHAR;
	YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars) + 1] = YY_END_OF_BUFFER_CHAR;

	(yytext_ptr) = &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[0];

	return ret_val;
}

/* yy_get_previous_state - get the state just before the EOB char was reached */

    static yy_state_type yy_get_previous_state (void)
{
	yy_state_type yy_current_state;
	char *yy_cp;
    
	yy_current_state = (yy_start);

	(yy_state_ptr) = (yy_state_buf);
	*(yy_state_ptr)++ = yy_current_state;

	for ( yy_cp = (yytext_ptr) + YY_MORE_ADJ; yy_cp < (yy_c_buf_p); ++yy_cp )
		{
		YY_CHAR yy_c = (*yy_cp ? yy_ec[YY_SC_TO_UI(*yy_cp)] : 1);
		while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
			{
			yy_current_state = (int) yy_def[yy_current_state];
			if ( yy_current_state >= 850 )
				yy_c = yy_meta[yy_c];
			}
		yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
		*(yy_state_ptr)++ = yy_current_state;
		}

	return yy_current_state;
}

/* yy_try_NUL_trans - try to make a transition on the NUL character
 *
 * synopsis
 *	next_state = yy_try_NUL_trans( current_state );
 */
    static yy_state_type yy_try_NUL_trans  (yy_state_type yy_current_state )
{
	int yy_is_jam;
    
	YY_CHAR yy_c = 1;
	while ( yy_chk[yy_base[yy_current_state] + yy_c] != yy_current_state )
		{
		yy_current_state = (int) yy_def[yy_current_state];
		if ( yy_current_state >= 850 )
			yy_c = yy_meta[yy_c];
		}
	yy_current_state = yy_nxt[yy_base[yy_current_state] + yy_c];
	yy_is_jam = (yy_current_state == 849);
	if ( ! yy_is_jam )
		*(yy_state_ptr)++ = yy_current_state;

		return yy_is_jam ? 0 : yy_current_state;
}

#ifndef YY_NO_UNPUT

#endif

#ifndef YY_NO_INPUT
#ifdef __cplusplus
    static int yyinput (void)
#else
    static int input  (void)
#endif

{
	int c;
    
	*(yy_c_buf_p) = (yy_hold_char);

	if ( *(yy_c_buf_p) == YY_END_OF_BUFFER_CHAR )
		{
		/* yy_c_buf_p now points to the character we want to return.
		 * If this occurs *before* the EOB characters, then it's a
		 * valid NUL; if not, then we've hit the end of the buffer.
		 */
		if ( (yy_c_buf_p) < &YY_CURRENT_BUFFER_LVALUE->yy_ch_buf[(yy_n_chars)] )
			/* This was really a NUL. */
			*(yy_c_buf_p) = '\0';

		else
			{ /* need more input */
			int offset = (int) ((yy_c_buf_p) - (yytext_ptr));
			++(yy_c_buf_p);

			switch ( yy_get_next_buffer(  ) )
				{
				case EOB_ACT_LAST_MATCH:
					/* This happens because yy_g_n_b()
					 * sees that we've accumulated a
					 * token and flags that we need to
					 * try matching the token before
					 * proceeding.  But for input(),
					 * there's no matching to consider.
					 * So convert the EOB_ACT_LAST_MATCH
					 * to EOB_ACT_END_OF_FILE.
					 */

					/* Reset buffer status. */
					yyrestart( yyin );

					/*FALLTHROUGH*/

				case EOB_ACT_END_OF_FILE:
					{
					if ( yywrap(  ) )
						return 0;

					if ( ! (yy_did_buffer_switch_on_eof) )
						YY_NEW_FILE;
#ifdef __cplusplus
					return yyinput();
#else
					return input();
#endif
					}

				case EOB_ACT_CONTINUE_SCAN:
					(yy_c_buf_p) = (yytext_ptr) + offset;
					break;
				}
			}
		}

	c = *(unsigned char *) (yy_c_buf_p);	/* cast for 8-bit char's */
	*(yy_c_buf_p) = '\0';	/* preserve yytext */
	(yy_hold_char) = *++(yy_c_buf_p);

	return c;
}
#endif	/* ifndef YY_NO_INPUT */

/** Immediately switch to a different input stream.
 * @param input_file A readable stream.
 * 
 * @note This function does not reset the start condition to @c INITIAL .
 */
    void yyrestart  (FILE * input_file )
{
    
	if ( ! YY_CURRENT_BUFFER ){
        yyensure_buffer_stack ();
		YY_CURRENT_BUFFER_LVALUE =
            yy_create_buffer( yyin, YY_BUF_SIZE );
	}

	yy_init_buffer( YY_CURRENT_BUFFER, input_file );
	yy_load_buffer_state(  );
}

/** Switch to a different input buffer.
 * @param new_buffer The new input buffer.
 * 
 */
    void yy_switch_to_buffer  (YY_BUFFER_STATE  new_buffer )
{
    
	/* TODO. We should be able to replace this entire function body
	 * with
	 *		yypop_buffer_state();
	 *		yypush_buffer_state(new_buffer);
     */
	yyensure_buffer_stack ();
	if ( YY_CURRENT_BUFFER == new_buffer )
		return;

	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	YY_CURRENT_BUFFER_LVALUE = new_buffer;
	yy_load_buffer_state(  );

	/* We don't actually know whether we did this switch during
	 * EOF (yywrap()) processing, but the only time this flag
	 * is looked at is after yywrap() is called, so it's safe
	 * to go ahead and always set it.
	 */
	(yy_did_buffer_switch_on_eof) = 1;
}

static void yy_load_buffer_state  (void)
{
    	(yy_n_chars) = YY_CURRENT_BUFFER_LVALUE->yy_n_chars;
	(yytext_ptr) = (yy_c_buf_p) = YY_CURRENT_BUFFER_LVALUE->yy_buf_pos;
	yyin = YY_CURRENT_BUFFER_LVALUE->yy_input_file;
	(yy_hold_char) = *(yy_c_buf_p);
}

/** Allocate and initialize an input buffer state.
 * @param file A readable stream.
 * @param size The character buffer size in bytes. When in doubt, use @c YY_BUF_SIZE.
 * 
 * @return the allocated buffer state.
 */
    YY_BUFFER_STATE yy_create_buffer  (FILE * file, int  size )
{
	YY_BUFFER_STATE b;
    
	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_buf_size = size;

	/* yy_ch_buf has to be 2 characters longer than the size given because
	 * we need to put in 2 end-of-buffer characters.
	 */
	b->yy_ch_buf = (char *) yyalloc( (yy_size_t) (b->yy_buf_size + 2)  );
	if ( ! b->yy_ch_buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_create_buffer()" );

	b->yy_is_our_buffer = 1;

	yy_init_buffer( b, file );

	return b;
}

/** Destroy the buffer.
 * @param b a buffer created with yy_create_buffer()
 * 
 */
    void yy_delete_buffer (YY_BUFFER_STATE  b )
{
    
	if ( ! b )
		return;

	if ( b == YY_CURRENT_BUFFER ) /* Not sure if we should pop here. */
		YY_CURRENT_BUFFER_LVALUE = (YY_BUFFER_STATE) 0;

	if ( b->yy_is_our_buffer )
		yyfree( (void *) b->yy_ch_buf  );

	yyfree( (void *) b  );
}

/* Initializes or reinitializes a buffer.
 * This function is sometimes called more than once on the same buffer,
 * such as during a yyrestart() or at EOF.
 */
    static void yy_init_buffer  (YY_BUFFER_STATE  b, FILE * file )

{
	int oerrno = errno;
    
	yy_flush_buffer( b );

	b->yy_input_file = file;
	b->yy_fill_buffer = 1;

    /* If b is the current buffer, then yy_init_buffer was _probably_
     * called from yyrestart() or through yy_get_next_buffer.
     * In that case, we don't want to reset the lineno or column.
     */
    if (b != YY_CURRENT_BUFFER){
        b->yy_bs_lineno = 1;
        b->yy_bs_column = 0;
    }

        b->yy_is_interactive = file ? (isatty( fileno(file) ) > 0) : 0;
    
	errno = oerrno;
}

/** Discard all buffered characters. On the next scan, YY_INPUT will be called.
 * @param b the buffer state to be flushed, usually @c YY_CURRENT_BUFFER.
 * 
 */
    void yy_flush_buffer (YY_BUFFER_STATE  b )
{
    	if ( ! b )
		return;

	b->yy_n_chars = 0;

	/* We always need two end-of-buffer characters.  The first causes
	 * a transition to the end-of-buffer state.  The second causes
	 * a jam in that state.
	 */
	b->yy_ch_buf[0] = YY_END_OF_BUFFER_CHAR;
	b->yy_ch_buf[1] = YY_END_OF_BUFFER_CHAR;

	b->yy_buf_pos = &b->yy_ch_buf[0];

	b->yy_at_bol = 1;
	b->yy_buffer_status = YY_BUFFER_NEW;

	if ( b == YY_CURRENT_BUFFER )
		yy_load_buffer_state(  );
}

/** Pushes the new state onto the stack. The new state becomes
 *  the current state. This function will allocate the stack
 *  if necessary.
 *  @param new_buffer The new state.
 *  
 */
void yypush_buffer_state (YY_BUFFER_STATE new_buffer )
{
    	if (new_buffer == NULL)
		return;

	yyensure_buffer_stack();

	/* This block is copied from yy_switch_to_buffer. */
	if ( YY_CURRENT_BUFFER )
		{
		/* Flush out information for old buffer. */
		*(yy_c_buf_p) = (yy_hold_char);
		YY_CURRENT_BUFFER_LVALUE->yy_buf_pos = (yy_c_buf_p);
		YY_CURRENT_BUFFER_LVALUE->yy_n_chars = (yy_n_chars);
		}

	/* Only push if top exists. Otherwise, replace top. */
	if (YY_CURRENT_BUFFER)
		(yy_buffer_stack_top)++;
	YY_CURRENT_BUFFER_LVALUE = new_buffer;

	/* copied from yy_switch_to_buffer. */
	yy_load_buffer_state(  );
	(yy_did_buffer_switch_on_eof) = 1;
}

/** Removes and deletes the top of the stack, if present.
 *  The next element becomes the new top.
 *  
 */
void yypop_buffer_state (void)
{
    	if (!YY_CURRENT_BUFFER)
		return;

	yy_delete_buffer(YY_CURRENT_BUFFER );
	YY_CURRENT_BUFFER_LVALUE = NULL;
	if ((yy_buffer_stack_top) > 0)
		--(yy_buffer_stack_top);

	if (YY_CURRENT_BUFFER) {
		yy_load_buffer_state(  );
		(yy_did_buffer_switch_on_eof) = 1;
	}
}

/* Allocates the stack if it does not exist.
 *  Guarantees space for at least one push.
 */
static void yyensure_buffer_stack (void)
{
	yy_size_t num_to_alloc;
    
	if (!(yy_buffer_stack)) {

		/* First allocation is just for 2 elements, since we don't know if this
		 * scanner will even need a stack. We use 2 instead of 1 to avoid an
		 * immediate realloc on the next call.
         */
      num_to_alloc = 1; /* After all that talk, this was set to 1 anyways... */
		(yy_buffer_stack) = (struct yy_buffer_state**)yyalloc
								(num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		memset((yy_buffer_stack), 0, num_to_alloc * sizeof(struct yy_buffer_state*));

		(yy_buffer_stack_max) = num_to_alloc;
		(yy_buffer_stack_top) = 0;
		return;
	}

	if ((yy_buffer_stack_top) >= ((yy_buffer_stack_max)) - 1){

		/* Increase the buffer to prepare for a possible push. */
		yy_size_t grow_size = 8 /* arbitrary grow size */;

		num_to_alloc = (yy_buffer_stack_max) + grow_size;
		(yy_buffer_stack) = (struct yy_buffer_state**)yyrealloc
								((yy_buffer_stack),
								num_to_alloc * sizeof(struct yy_buffer_state*)
								);
		if ( ! (yy_buffer_stack) )
			YY_FATAL_ERROR( "out of dynamic memory in yyensure_buffer_stack()" );

		/* zero only the new slots.*/
		memset((yy_buffer_stack) + (yy_buffer_stack_max), 0, grow_size * sizeof(struct yy_buffer_state*));
		(yy_buffer_stack_max) = num_to_alloc;
	}
}

/** Setup the input buffer state to scan directly from a user-specified character buffer.
 * @param base the character buffer
 * @param size the size in bytes of the character buffer
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_buffer  (char * base, yy_size_t  size )
{
	YY_BUFFER_STATE b;
    
	if ( size < 2 ||
	     base[size-2] != YY_END_OF_BUFFER_CHAR ||
	     base[size-1] != YY_END_OF_BUFFER_CHAR )
		/* They forgot to leave room for the EOB's. */
		return NULL;

	b = (YY_BUFFER_STATE) yyalloc( sizeof( struct yy_buffer_state )  );
	if ( ! b )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_buffer()" );

	b->yy_buf_size = (int) (size - 2);	/* "- 2" to take care of EOB's */
	b->yy_buf_pos = b->yy_ch_buf = base;
	b->yy_is_our_buffer = 0;
	b->yy_input_file = NULL;
	b->yy_n_chars = b->yy_buf_size;
	b->yy_is_interactive = 0;
	b->yy_at_bol = 1;
	b->yy_fill_buffer = 0;
	b->yy_buffer_status = YY_BUFFER_NEW;

	yy_switch_to_buffer( b  );

	return b;
}

/** Setup the input buffer state to scan a string. The next call to yylex() will
 * scan from a @e copy of @a str.
 * @param yystr a NUL-terminated string to scan
 * 
 * @return the newly allocated buffer state object.
 * @note If you want to scan bytes that may contain NUL values, then use
 *       yy_scan_bytes() instead.
 */
YY_BUFFER_STATE yy_scan_string (const char * yystr )
{
    
	return yy_scan_bytes( yystr, (int) strlen(yystr) );
}

/** Setup the input buffer state to scan the given bytes. The next call to yylex() will
 * scan from a @e copy of @a bytes.
 * @param yybytes the byte buffer to scan
 * @param _yybytes_len the number of bytes in the buffer pointed to by @a bytes.
 * 
 * @return the newly allocated buffer state object.
 */
YY_BUFFER_STATE yy_scan_bytes  (const char * yybytes, int  _yybytes_len )
{
	YY_BUFFER_STATE b;
	char *buf;
	yy_size_t n;
	int i;
    
	/* Get memory for full buffer, including space for trailing EOB's. */
	n = (yy_size_t) (_yybytes_len + 2);
	buf = (char *) yyalloc( n  );
	if ( ! buf )
		YY_FATAL_ERROR( "out of dynamic memory in yy_scan_bytes()" );

	for ( i = 0; i < _yybytes_len; ++i )
		buf[i] = yybytes[i];

	buf[_yybytes_len] = buf[_yybytes_len+1] = YY_END_OF_BUFFER_CHAR;

	b = yy_scan_buffer( buf, n );
	if ( ! b )
		YY_FATAL_ERROR( "bad buffer in yy_scan_bytes()" );

	/* It's okay to grow etc. this buffer, and we should throw it
	 * away when we're done.
	 */
	b->yy_is_our_buffer = 1;

	return b;
}

#ifndef YY_EXIT_FAILURE
#define YY_EXIT_FAILURE 2
#endif

static void yynoreturn yy_fatal_error (const char* msg )
{
			fprintf( stderr, "%s\n", msg );
	exit( YY_EXIT_FAILURE );
}

/* Redefine yyless() so it works in section 3 code. */

#undef yyless
#define yyless(n) \
	do \
		{ \
		/* Undo effects of setting up yytext. */ \
        int yyless_macro_arg = (n); \
        YY_LESS_LINENO(yyless_macro_arg);\
		yytext[yyleng] = (yy_hold_char); \
		(yy_c_buf_p) = yytext + yyless_macro_arg; \
		(yy_hold_char) = *(yy_c_buf_p); \
		*(yy_c_buf_p) = '\0'; \
		yyleng = yyless_macro_arg; \
		} \
	while ( 0 )

/* Accessor  methods (get/set functions) to struct members. */

/** Get the current line number.
 * 
 */
int yyget_lineno  (void)
{
    
    return yylineno;
}

/** Get the input stream.
 * 
 */
FILE *yyget_in  (void)
{
        return yyin;
}

/** Get the output stream.
 * 
 */
FILE *yyget_out  (void)
{
        return yyout;
}

/** Get the length of the current token.
 * 
 */
int yyget_leng  (void)
{
        return yyleng;
}

/** Get the current token.
 * 
 */

char *yyget_text  (void)
{
        return yytext;
}

/** Set the current line number.
 * @param _line_number line number
 * 
 */
void yyset_lineno (int  _line_number )
{
    
    yylineno = _line_number;
}

/** Set the input stream. This does not discard the current
 * input buffer.
 * @param _in_str A readable stream.
 * 
 * @see yy_switch_to_buffer
 */
void yyset_in (FILE *  _in_str )
{
        yyin = _in_str ;
}

void yyset_out (FILE *  _out_str )
{
        yyout = _out_str ;
}

int yyget_debug  (void)
{
        return yy_flex_debug;
}

void yyset_debug (int  _bdebug )
{
        yy_flex_debug = _bdebug ;
}

static int yy_init_globals (void)
{
        /* Initialization is the same as for the non-reentrant scanner.
     * This function is called from yylex_destroy(), so don't allocate here.
     */

    (yy_buffer_stack) = NULL;
    (yy_buffer_stack_top) = 0;
    (yy_buffer_stack_max) = 0;
    (yy_c_buf_p) = NULL;
    (yy_init) = 0;
    (yy_start) = 0;

    (yy_state_buf) = 0;
    (yy_state_ptr) = 0;
    (yy_full_match) = 0;
    (yy_lp) = 0;

/* Defined in main.c */
#ifdef YY_STDINIT
    yyin = stdin;
    yyout = stdout;
#else
    yyin = NULL;
    yyout = NULL;
#endif

    /* For future reference: Set errno on error, since we are called by
     * yylex_init()
     */
    return 0;
}

/* yylex_destroy is for both reentrant and non-reentrant scanners. */
int yylex_destroy  (void)
{
    
    /* Pop the buffer stack, destroying each element. */
	while(YY_CURRENT_BUFFER){
		yy_delete_buffer( YY_CURRENT_BUFFER  );
		YY_CURRENT_BUFFER_LVALUE = NULL;
		yypop_buffer_state();
	}

	/* Destroy the stack itself. */
	yyfree((yy_buffer_stack) );
	(yy_buffer_stack) = NULL;

    yyfree ( (yy_state_buf) );
    (yy_state_buf)  = NULL;

    /* Reset the globals. This is important in a non-reentrant scanner so the next time
     * yylex() is called, initialization will occur. */
    yy_init_globals( );

    return 0;
}

/*
 * Internal utility routines.
 */

#ifndef yytext_ptr
static void yy_flex_strncpy (char* s1, const char * s2, int n )
{
		
	int i;
	for ( i = 0; i < n; ++i )
		s1[i] = s2[i];
}
#endif

#ifdef YY_NEED_STRLEN
static int yy_flex_strlen (const char * s )
{
	int n;
	for ( n = 0; s[n]; ++n )
		;

	return n;
}
#endif

void *yyalloc (yy_size_t  size )
{
			return malloc(size);
}

void *yyrealloc  (void * ptr, yy_size_t  size )
{
		
	/* The cast to (char *) in the following accommodates both
	 * implementations that use char* generic pointers, and those
	 * that use void* generic pointers.  It works with the latter
	 * because both ANSI C and C++ allow castless assignment from
	 * any pointer type to void*, and deal with argument conversions
	 * as though doing an assignment.
	 */
	return realloc(ptr, size);
}

void yyfree (void * ptr )
{
			free( (char *) ptr );	/* see yyrealloc() for (char *) cast */
}

#define YYTABLES_NAME "yytables"

#line 289 "../gobject-introspection/giscanner/scannerlexer.l"


static int
yywrap (void)
{
  return 1;
}

static void
parse_comment (GISourceScanner *scanner)
{
  int c1, c2;
  GString *string = NULL;
  GISourceComment *comment;
  int comment_lineno;
  int skip = FALSE;

  c1 = input();
  c2 = input();

  if (c2 != IS_EOF && (c1 == '*' && c2 != '*' && c2 != '/')) {
    /*
     * Store GTK-Doc comment blocks,
     * starts with one '/' followed by exactly two '*' and not followed by a '/'
     */
    if (!g_hash_table_contains (scanner->files, scanner->current_file)) {
        skip = TRUE;
    } else {
        string = g_string_new (yytext);
    }

    comment_lineno = lineno;

    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (!skip)
          g_string_append_c (string, c1);

        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    if (skip) {
        return;
    }

    g_string_append (string, "*/");

    comment = g_slice_new (GISourceComment);
    comment->comment = g_string_free (string, FALSE);
    comment->line = comment_lineno;
    comment->filename = g_file_get_parse_name (scanner->current_file);

    gi_source_scanner_take_comment (scanner, comment);
  } else {
    /*
     * Ignore all other comment blocks
     */
    while (c2 != IS_EOF && !(c1 == '*' && c2 == '/'))
      {
        if (c1 == '\n')
          lineno++;

        c1 = c2;
        c2 = input();
      }

    return;
  }
}

static int
check_identifier (GISourceScanner *scanner,
		  const char  *s)
{
	/*
	 * This function checks if `s' is a type name or an
	 * identifier.
	 */

	if (gi_source_scanner_is_typedef (scanner, s)) {
		return TYPEDEF_NAME;
	} else if (strcmp (s, "__builtin_va_list") == 0) {
		return TYPEDEF_NAME;
	}

	return IDENTIFIER;
}

/* taken from glib/gfileutils.c */
#if defined(MAXPATHLEN)
#define G_PATH_LENGTH MAXPATHLEN
#elif defined(PATH_MAX)
#define G_PATH_LENGTH PATH_MAX
#elif defined(_PC_PATH_MAX)
#define G_PATH_LENGTH sysconf(_PC_PATH_MAX)
#else
#define G_PATH_LENGTH 2048
#endif

#ifdef _WIN32
/* We don't want to include <windows.h> as it clashes horribly
 * with token names from scannerparser.h. So just declare
 * GetFullPathNameA() here unless we already defined it, like
 * in giscanner.c.
 */
extern unsigned long __stdcall GetFullPathNameA(const char*, int, char*, char**);
#endif

static inline char *
_realpath (const char *path)
{
#ifndef _WIN32
  char buffer[G_PATH_LENGTH];

  return realpath (path, buffer) ? g_strdup (buffer) : NULL;
#else
  char *buffer;
  char dummy;
  int rc, len;

  rc = GetFullPathNameA (path, 1, &dummy, NULL);
  if (rc == 0)
    {
      /* Weird failure, so just return the input path as such */
      return g_strdup (path);
    }

  len = rc + 1;
  buffer = g_malloc (len);

  rc = GetFullPathNameA (path, len, buffer, NULL);
  if (rc == 0 || rc > len)
    {
      /* Weird failure again */
      g_free (buffer);
      return g_strdup (path);
    }
  return buffer;
#endif
}

/*
 * # linenum "filename" flags
 *  See http://gcc.gnu.org/onlinedocs/cpp/Preprocessor-Output.html
 **/

static void
process_linemarks (GISourceScanner *scanner, gboolean has_line)
{
	char escaped_filename[1025];
	char *filename;
	char *real;

	if (has_line)
		sscanf(yytext, "#line %d \"%1024[^\"]\"", &lineno, escaped_filename);
	else
		sscanf(yytext, "# %d \"%1024[^\"]\"", &lineno, escaped_filename);

	filename = g_strcompress (escaped_filename);

        real = _realpath (filename);
        if (real)
          {
            g_free (filename);
            filename = real;
          }

        if (scanner->current_file)
          g_object_unref (scanner->current_file);
	scanner->current_file = g_file_new_for_path (filename);
	g_free (filename);
}

/*
 * This parses a macro which is ignored, such as
 * __attribute__((x)) or __asm__ (x)
 */
static int
parse_ignored_macro (void)
{
	int c;
	int nest;

	while ((c = input ()) != IS_EOF && isspace (c))
		;
	if (c != '(')
		return FALSE;

	nest = 0;
	while ((c = input ()) != IS_EOF && (nest > 0 || c != ')')) {
		if (c == '(')
			nest++;
		else if (c == ')')
			nest--;
		else if (c == '"') {
			while ((c = input ()) != IS_EOF && c != '"') {
				if (c == '\\')
					c = input ();
			}
		} else if (c == '\'') {
			c = input ();
			if (c == '\\')
				c = input ();
			else if (c == '\'')
				return FALSE;
			c = input ();
			if (c != '\'')
				return FALSE;
		} else if (c == '\n')
			lineno++;
	}

	return TRUE;
}

static void
parse_trigraph (GISourceScanner *scanner)
{
	char **items;
	char *start, *end;
	int i;

	start = g_strstr_len (yytext, yyleng, "<");
	g_assert (start != NULL);
	end = g_strstr_len (yytext, yyleng, ">");
	g_assert (end != NULL);
	*end = '\0';
	items = g_strsplit (start + 1, ",", 0);
	for (i = 0; items[i] != NULL; i++) {
		char *item = items[i];
		g_strstrip (item);
		if (strcmp (item, "public") == 0)
			scanner->private = FALSE;
		else if (strcmp (item, "private") == 0)
			scanner->private = TRUE;
		else if (strcmp (item, "flags") == 0)
			scanner->flags = TRUE;
	}
	g_strfreev (items);
}

static void
print_error (GISourceScanner *scanner)
{
  if (yytext[0]) {
    char *filename = g_file_get_parse_name (scanner->current_file);
    gchar *error = g_strdup_printf ("%s:%d: unexpected character `%c'", filename, lineno, yytext[0]);
    g_ptr_array_add (scanner->errors, error);
    g_free (filename);
  }
}

